# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtTest, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtTest`

import PySide6.QtTest
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import SignalInstance
from shiboken6 import Shiboken


class QAbstractItemModelTester(PySide6.QtCore.QObject):

    class FailureReportingMode(enum.Enum):

        QtTest                    = 0x0
        Warning                   = 0x1
        Fatal                     = 0x2


    @typing.overload
    def __init__(self, model: PySide6.QtCore.QAbstractItemModel, mode: PySide6.QtTest.QAbstractItemModelTester.FailureReportingMode, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, model: PySide6.QtCore.QAbstractItemModel, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def failureReportingMode(self, /) -> PySide6.QtTest.QAbstractItemModelTester.FailureReportingMode: ...
    def model(self, /) -> PySide6.QtCore.QAbstractItemModel: ...
    def setUseFetchMore(self, value: bool, /) -> None: ...


class QIntList: ...


class QSignalSpy(Shiboken.Object):

    @typing.overload
    def __init__(self, obj: PySide6.QtCore.QObject, signal: PySide6.QtCore.QMetaMethod, /) -> None: ...
    @typing.overload
    def __init__(self, obj: PySide6.QtCore.QObject, aSignal: bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def __init__(self, signal: PySide6.QtCore.SignalInstance, /) -> None: ...

    def at(self, arg__1: int, /) -> typing.List[typing.Any]: ...
    def count(self, /) -> int: ...
    def isValid(self, /) -> bool: ...
    def signal(self, /) -> PySide6.QtCore.QByteArray: ...
    def size(self, /) -> int: ...
    def wait(self, timeout: int, /) -> bool: ...


class QTest(Shiboken.Object):

    class ComparisonOperation(enum.Enum):

        CustomCompare             = 0x0
        Equal                     = 0x1
        NotEqual                  = 0x2
        LessThan                  = 0x3
        LessThanOrEqual           = 0x4
        GreaterThan               = 0x5
        GreaterThanOrEqual        = 0x6
        ThreeWayCompare           = 0x7

    class KeyAction(enum.Enum):

        Press                     = 0x0
        Release                   = 0x1
        Click                     = 0x2
        Shortcut                  = 0x3

    class MouseAction(enum.Enum):

        MousePress                = 0x0
        MouseRelease              = 0x1
        MouseClick                = 0x2
        MouseDClick               = 0x3
        MouseMove                 = 0x4

    class QBenchmarkMetric(enum.Enum):

        FramesPerSecond           = 0x0
        BitsPerSecond             = 0x1
        BytesPerSecond            = 0x2
        WalltimeMilliseconds      = 0x3
        CPUTicks                  = 0x4
        InstructionReads          = 0x5
        Events                    = 0x6
        WalltimeNanoseconds       = 0x7
        BytesAllocated            = 0x8
        CPUMigrations             = 0x9
        CPUCycles                 = 0xa
        BusCycles                 = 0xb
        StalledCycles             = 0xc
        Instructions              = 0xd
        BranchInstructions        = 0xe
        BranchMisses              = 0xf
        CacheReferences           = 0x10
        CacheReads                = 0x11
        CacheWrites               = 0x12
        CachePrefetches           = 0x13
        CacheMisses               = 0x14
        CacheReadMisses           = 0x15
        CacheWriteMisses          = 0x16
        CachePrefetchMisses       = 0x17
        ContextSwitches           = 0x18
        PageFaults                = 0x19
        MinorPageFaults           = 0x1a
        MajorPageFaults           = 0x1b
        AlignmentFaults           = 0x1c
        EmulationFaults           = 0x1d
        RefCPUCycles              = 0x1e

    class QTouchEventSequence(Shiboken.Object):
        def commit(self, /, processEvents: bool = ...) -> None: ...
        @typing.overload
        def move(self, touchId: int, pt: PySide6.QtCore.QPoint, /, widget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        @typing.overload
        def move(self, touchId: int, pt: PySide6.QtCore.QPoint, /, window: PySide6.QtGui.QWindow | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        @typing.overload
        def press(self, touchId: int, pt: PySide6.QtCore.QPoint, /, widget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        @typing.overload
        def press(self, touchId: int, pt: PySide6.QtCore.QPoint, /, window: PySide6.QtGui.QWindow | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        @typing.overload
        def release(self, touchId: int, pt: PySide6.QtCore.QPoint, /, widget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        @typing.overload
        def release(self, touchId: int, pt: PySide6.QtCore.QPoint, /, window: PySide6.QtGui.QWindow | None = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
        def stationary(self, touchId: int, /) -> PySide6.QtTest.QTest.QTouchEventSequence: ...

    class TestFailMode(enum.Enum):

        Abort                     = 0x1
        Continue                  = 0x2


    @staticmethod
    def addColumnInternal(id: int, name: bytes | bytearray | memoryview, /) -> None: ...
    @staticmethod
    def asciiToKey(ascii: int, /) -> PySide6.QtCore.Qt.Key: ...
    @typing.overload
    @staticmethod
    def compare_ptr_helper(t1: PySide6.QtCore.QObject, t2: PySide6.QtCore.QObject, actual: bytes | bytearray | memoryview, expected: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def compare_ptr_helper(t1: int, t2: int, actual: bytes | bytearray | memoryview, expected: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> bool: ...
    @staticmethod
    def compare_string_helper(t1: bytes | bytearray | memoryview, t2: bytes | bytearray | memoryview, actual: bytes | bytearray | memoryview, expected: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> bool: ...
    @staticmethod
    def createTouchDevice(devType: PySide6.QtGui.QInputDevice.DeviceType = ..., caps: PySide6.QtGui.QInputDevice.Capability = ...) -> PySide6.QtGui.QPointingDevice: ...
    @staticmethod
    def currentAppName() -> bytes | bytearray | memoryview: ...
    @staticmethod
    def currentDataTag() -> bytes | bytearray | memoryview: ...
    @staticmethod
    def currentGlobalDataTag() -> bytes | bytearray | memoryview: ...
    @staticmethod
    def currentTestFailed() -> bool: ...
    @staticmethod
    def currentTestFunction() -> bytes | bytearray | memoryview: ...
    @staticmethod
    def currentTestResolved() -> bool: ...
    @typing.overload
    @staticmethod
    def failOnWarning() -> None: ...
    @typing.overload
    @staticmethod
    def failOnWarning(messagePattern: PySide6.QtCore.QRegularExpression | str, /) -> None: ...
    @typing.overload
    @staticmethod
    def failOnWarning(message: bytes | bytearray | memoryview, /) -> None: ...
    @staticmethod
    def formatString(prefix: bytes | bytearray | memoryview, suffix: bytes | bytearray | memoryview, numArguments: int, /) -> bytes | bytearray | memoryview: ...
    @typing.overload
    @staticmethod
    def ignoreMessage(type: PySide6.QtCore.QtMsgType, messagePattern: PySide6.QtCore.QRegularExpression | str, /) -> None: ...
    @typing.overload
    @staticmethod
    def ignoreMessage(type: PySide6.QtCore.QtMsgType, message: bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    @staticmethod
    def keyClick(widget: PySide6.QtWidgets.QWidget, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyClick(widget: PySide6.QtWidgets.QWidget, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyClick(window: PySide6.QtGui.QWindow, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyClick(window: PySide6.QtGui.QWindow, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @staticmethod
    def keyClicks(widget: PySide6.QtWidgets.QWidget, sequence: str, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyEvent(action: PySide6.QtTest.QTest.KeyAction, widget: PySide6.QtWidgets.QWidget, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyEvent(action: PySide6.QtTest.QTest.KeyAction, widget: PySide6.QtWidgets.QWidget, ascii: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyEvent(action: PySide6.QtTest.QTest.KeyAction, window: PySide6.QtGui.QWindow, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyEvent(action: PySide6.QtTest.QTest.KeyAction, window: PySide6.QtGui.QWindow, ascii: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyPress(widget: PySide6.QtWidgets.QWidget, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyPress(widget: PySide6.QtWidgets.QWidget, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyPress(window: PySide6.QtGui.QWindow, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyPress(window: PySide6.QtGui.QWindow, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyRelease(widget: PySide6.QtWidgets.QWidget, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyRelease(widget: PySide6.QtWidgets.QWidget, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyRelease(window: PySide6.QtGui.QWindow, key: PySide6.QtCore.Qt.Key, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keyRelease(window: PySide6.QtGui.QWindow, key: int, /, modifier: PySide6.QtCore.Qt.KeyboardModifier = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def keySequence(widget: PySide6.QtWidgets.QWidget, keySequence: PySide6.QtGui.QKeySequence | PySide6.QtCore.QKeyCombination | PySide6.QtGui.QKeySequence.StandardKey | str | int, /) -> None: ...
    @typing.overload
    @staticmethod
    def keySequence(window: PySide6.QtGui.QWindow, keySequence: PySide6.QtGui.QKeySequence | PySide6.QtCore.QKeyCombination | PySide6.QtGui.QKeySequence.StandardKey | str | int, /) -> None: ...
    @staticmethod
    def keyToAscii(key: PySide6.QtCore.Qt.Key, /) -> int: ...
    @typing.overload
    @staticmethod
    def mouseClick(widget: PySide6.QtWidgets.QWidget, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseClick(window: PySide6.QtGui.QWindow, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseDClick(widget: PySide6.QtWidgets.QWidget, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseDClick(window: PySide6.QtGui.QWindow, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseEvent(action: PySide6.QtTest.QTest.MouseAction, widget: PySide6.QtWidgets.QWidget, button: PySide6.QtCore.Qt.MouseButton, stateKey: PySide6.QtCore.Qt.KeyboardModifier, pos: PySide6.QtCore.QPoint, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseEvent(action: PySide6.QtTest.QTest.MouseAction, window: PySide6.QtGui.QWindow, button: PySide6.QtCore.Qt.MouseButton, stateKey: PySide6.QtCore.Qt.KeyboardModifier, pos: PySide6.QtCore.QPoint, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseMove(widget: PySide6.QtWidgets.QWidget, /, pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseMove(window: PySide6.QtGui.QWindow, /, pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mousePress(widget: PySide6.QtWidgets.QWidget, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mousePress(window: PySide6.QtGui.QWindow, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseRelease(widget: PySide6.QtWidgets.QWidget, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def mouseRelease(window: PySide6.QtGui.QWindow, button: PySide6.QtCore.Qt.MouseButton, /, stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., pos: PySide6.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def qCaught(expected: bytes | bytearray | memoryview, what: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> None: ...
    @typing.overload
    @staticmethod
    def qCaught(expected: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> None: ...
    @staticmethod
    def qCleanup() -> None: ...
    @staticmethod
    def qElementData(elementName: bytes | bytearray | memoryview, metaTypeId: int, /) -> int: ...
    @staticmethod
    def qExpectFail(dataIndex: bytes | bytearray | memoryview, comment: bytes | bytearray | memoryview, mode: PySide6.QtTest.QTest.TestFailMode, file: bytes | bytearray | memoryview, line: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qFindTestData(basepath: str, /, file: bytes | bytearray | memoryview | None = ..., line: int | None = ..., builddir: bytes | bytearray | memoryview | None = ..., sourcedir: bytes | bytearray | memoryview | None = ...) -> str: ...
    @typing.overload
    @staticmethod
    def qFindTestData(basepath: bytes | bytearray | memoryview, /, file: bytes | bytearray | memoryview | None = ..., line: int | None = ..., builddir: bytes | bytearray | memoryview | None = ..., sourcedir: bytes | bytearray | memoryview | None = ...) -> str: ...
    @staticmethod
    def qGlobalData(tagName: bytes | bytearray | memoryview, typeId: int, /) -> int: ...
    @staticmethod
    def qRun() -> int: ...
    @staticmethod
    def qSkip(message: bytes | bytearray | memoryview, file: bytes | bytearray | memoryview, line: int, /) -> None: ...
    @staticmethod
    def qSleep(ms: int, /) -> None: ...
    @staticmethod
    def qWait(ms: int, /) -> None: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(widget: PySide6.QtWidgets.QWidget, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(widget: PySide6.QtWidgets.QWidget, timeout: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(widget: PySide6.QtWidgets.QWidget, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(window: PySide6.QtGui.QWindow, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(window: PySide6.QtGui.QWindow, timeout: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowActive(window: PySide6.QtGui.QWindow, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(widget: PySide6.QtWidgets.QWidget, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(widget: PySide6.QtWidgets.QWidget, timeout: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(widget: PySide6.QtWidgets.QWidget, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(window: PySide6.QtGui.QWindow, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(window: PySide6.QtGui.QWindow, timeout: int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowExposed(window: PySide6.QtGui.QWindow, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowFocused(widget: PySide6.QtWidgets.QWidget, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowFocused(widget: PySide6.QtWidgets.QWidget, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowFocused(window: PySide6.QtGui.QWindow, /) -> bool: ...
    @typing.overload
    @staticmethod
    def qWaitForWindowFocused(window: PySide6.QtGui.QWindow, timeout: PySide6.QtCore.QDeadlineTimer | PySide6.QtCore.QDeadlineTimer.ForeverConstant | int, /) -> bool: ...
    @staticmethod
    def runningTest() -> bool: ...
    @typing.overload
    @staticmethod
    def sendKeyEvent(action: PySide6.QtTest.QTest.KeyAction, widget: PySide6.QtWidgets.QWidget, code: PySide6.QtCore.Qt.Key, text: str, modifier: PySide6.QtCore.Qt.KeyboardModifier, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def sendKeyEvent(action: PySide6.QtTest.QTest.KeyAction, widget: PySide6.QtWidgets.QWidget, code: PySide6.QtCore.Qt.Key, ascii: int, modifier: PySide6.QtCore.Qt.KeyboardModifier, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def sendKeyEvent(action: PySide6.QtTest.QTest.KeyAction, window: PySide6.QtGui.QWindow, code: PySide6.QtCore.Qt.Key, text: str, modifier: PySide6.QtCore.Qt.KeyboardModifier, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def sendKeyEvent(action: PySide6.QtTest.QTest.KeyAction, window: PySide6.QtGui.QWindow, code: PySide6.QtCore.Qt.Key, ascii: int, modifier: PySide6.QtCore.Qt.KeyboardModifier, /, delay: int = ...) -> None: ...
    @staticmethod
    def setBenchmarkResult(result: float, metric: PySide6.QtTest.QTest.QBenchmarkMetric, /) -> None: ...
    @staticmethod
    def setMainSourcePath(file: bytes | bytearray | memoryview, /, builddir: bytes | bytearray | memoryview | None = ...) -> None: ...
    @staticmethod
    def setThrowOnFail(enable: bool, /) -> None: ...
    @staticmethod
    def setThrowOnSkip(enable: bool, /) -> None: ...
    @typing.overload
    @staticmethod
    def simulateEvent(widget: PySide6.QtWidgets.QWidget, press: bool, code: int, modifier: PySide6.QtCore.Qt.KeyboardModifier, text: str, repeat: bool, /, delay: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def simulateEvent(window: PySide6.QtGui.QWindow, press: bool, code: int, modifier: PySide6.QtCore.Qt.KeyboardModifier, text: str, repeat: bool, /, delay: int = ...) -> None: ...
    @staticmethod
    def testObject() -> PySide6.QtCore.QObject: ...
    @staticmethod
    def toPrettyCString(unicode: bytes | bytearray | memoryview, length: int, /) -> bytes | bytearray | memoryview: ...
    @typing.overload
    @staticmethod
    def touchEvent(widget: PySide6.QtWidgets.QWidget, device: PySide6.QtGui.QPointingDevice, /, autoCommit: bool = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
    @typing.overload
    @staticmethod
    def touchEvent(window: PySide6.QtGui.QWindow, device: PySide6.QtGui.QPointingDevice, /, autoCommit: bool = ...) -> PySide6.QtTest.QTest.QTouchEventSequence: ...
    @staticmethod
    def wheelEvent(window: PySide6.QtGui.QWindow, pos: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint, angleDelta: PySide6.QtCore.QPoint, /, pixelDelta: PySide6.QtCore.QPoint = ..., stateKey: PySide6.QtCore.Qt.KeyboardModifier = ..., phase: PySide6.QtCore.Qt.ScrollPhase = ...) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.Qt3DInput, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.Qt3DInput`

import PySide6.Qt3DInput
import PySide6.QtCore
import PySide6.QtGui
import PySide6.Qt3DCore

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class Qt3DInput(Shiboken.Object):

    class QAbstractActionInput(PySide6.Qt3DCore.Qt3DCore.QNode): ...

    class QAbstractAxisInput(PySide6.Qt3DCore.Qt3DCore.QNode):

        sourceDeviceChanged      : typing.ClassVar[Signal] = ... # sourceDeviceChanged(QAbstractPhysicalDevice*)
        def setSourceDevice(self, sourceDevice: PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice, /) -> None: ...
        def sourceDevice(self, /) -> PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice: ...

    class QAbstractPhysicalDevice(PySide6.Qt3DCore.Qt3DCore.QNode):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...

        def addAxisSetting(self, axisSetting: PySide6.Qt3DInput.Qt3DInput.QAxisSetting, /) -> None: ...
        def axisCount(self, /) -> int: ...
        def axisIdentifier(self, name: str, /) -> int: ...
        def axisNames(self, /) -> typing.List[str]: ...
        def axisSettings(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAxisSetting]: ...
        def buttonCount(self, /) -> int: ...
        def buttonIdentifier(self, name: str, /) -> int: ...
        def buttonNames(self, /) -> typing.List[str]: ...
        def removeAxisSetting(self, axisSetting: PySide6.Qt3DInput.Qt3DInput.QAxisSetting, /) -> None: ...

    class QAction(PySide6.Qt3DCore.Qt3DCore.QNode):

        activeChanged            : typing.ClassVar[Signal] = ... # activeChanged(bool)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, active: bool | None = ...) -> None: ...

        def addInput(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...
        def inputs(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput]: ...
        def isActive(self, /) -> bool: ...
        def removeInput(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...

    class QActionInput(PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput):

        buttonsChanged           : typing.ClassVar[Signal] = ... # buttonsChanged(QList<int>)
        sourceDeviceChanged      : typing.ClassVar[Signal] = ... # sourceDeviceChanged(QAbstractPhysicalDevice*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sourceDevice: PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice | None = ..., buttons: collections.abc.Sequence[int] | None = ...) -> None: ...

        def buttons(self, /) -> typing.List[int]: ...
        def setButtons(self, buttons: collections.abc.Sequence[int], /) -> None: ...
        def setSourceDevice(self, sourceDevice: PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice, /) -> None: ...
        def sourceDevice(self, /) -> PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice: ...

    class QAnalogAxisInput(PySide6.Qt3DInput.Qt3DInput.QAbstractAxisInput):

        axisChanged              : typing.ClassVar[Signal] = ... # axisChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, axis: int | None = ...) -> None: ...

        def axis(self, /) -> int: ...
        def setAxis(self, axis: int, /) -> None: ...

    class QAxis(PySide6.Qt3DCore.Qt3DCore.QNode):

        valueChanged             : typing.ClassVar[Signal] = ... # valueChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, value: float | None = ...) -> None: ...

        def addInput(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractAxisInput, /) -> None: ...
        def inputs(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAbstractAxisInput]: ...
        def removeInput(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractAxisInput, /) -> None: ...
        def value(self, /) -> float: ...

    class QAxisAccumulator(PySide6.Qt3DCore.Qt3DCore.QComponent):

        scaleChanged             : typing.ClassVar[Signal] = ... # scaleChanged(float)
        sourceAxisChanged        : typing.ClassVar[Signal] = ... # sourceAxisChanged(Qt3DInput::QAxis*)
        sourceAxisTypeChanged    : typing.ClassVar[Signal] = ... # sourceAxisTypeChanged(QAxisAccumulator::SourceAxisType)
        valueChanged             : typing.ClassVar[Signal] = ... # valueChanged(float)
        velocityChanged          : typing.ClassVar[Signal] = ... # velocityChanged(float)

        class SourceAxisType(enum.Enum):

            Velocity                  = 0x0
            Acceleration              = 0x1


        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sourceAxis: PySide6.Qt3DInput.Qt3DInput.QAxis | None = ..., sourceAxisType: PySide6.Qt3DInput.Qt3DInput.QAxisAccumulator.SourceAxisType | None = ..., scale: float | None = ..., value: float | None = ..., velocity: float | None = ...) -> None: ...

        def scale(self, /) -> float: ...
        def setScale(self, scale: float, /) -> None: ...
        def setSourceAxis(self, sourceAxis: PySide6.Qt3DInput.Qt3DInput.QAxis, /) -> None: ...
        def setSourceAxisType(self, sourceAxisType: PySide6.Qt3DInput.Qt3DInput.QAxisAccumulator.SourceAxisType, /) -> None: ...
        def sourceAxis(self, /) -> PySide6.Qt3DInput.Qt3DInput.QAxis: ...
        def sourceAxisType(self, /) -> PySide6.Qt3DInput.Qt3DInput.QAxisAccumulator.SourceAxisType: ...
        def value(self, /) -> float: ...
        def velocity(self, /) -> float: ...

    class QAxisSetting(PySide6.Qt3DCore.Qt3DCore.QNode):

        axesChanged              : typing.ClassVar[Signal] = ... # axesChanged(QList<int>)
        deadZoneRadiusChanged    : typing.ClassVar[Signal] = ... # deadZoneRadiusChanged(float)
        smoothChanged            : typing.ClassVar[Signal] = ... # smoothChanged(bool)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, deadZoneRadius: float | None = ..., axes: collections.abc.Sequence[int] | None = ..., smooth: bool | None = ...) -> None: ...

        def axes(self, /) -> typing.List[int]: ...
        def deadZoneRadius(self, /) -> float: ...
        def isSmoothEnabled(self, /) -> bool: ...
        def setAxes(self, axes: collections.abc.Sequence[int], /) -> None: ...
        def setDeadZoneRadius(self, deadZoneRadius: float, /) -> None: ...
        def setSmoothEnabled(self, enabled: bool, /) -> None: ...

    class QButtonAxisInput(PySide6.Qt3DInput.Qt3DInput.QAbstractAxisInput):

        accelerationChanged      : typing.ClassVar[Signal] = ... # accelerationChanged(float)
        buttonsChanged           : typing.ClassVar[Signal] = ... # buttonsChanged(QList<int>)
        decelerationChanged      : typing.ClassVar[Signal] = ... # decelerationChanged(float)
        scaleChanged             : typing.ClassVar[Signal] = ... # scaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, scale: float | None = ..., buttons: collections.abc.Sequence[int] | None = ..., acceleration: float | None = ..., deceleration: float | None = ...) -> None: ...

        def acceleration(self, /) -> float: ...
        def buttons(self, /) -> typing.List[int]: ...
        def deceleration(self, /) -> float: ...
        def scale(self, /) -> float: ...
        def setAcceleration(self, acceleration: float, /) -> None: ...
        def setButtons(self, buttons: collections.abc.Sequence[int], /) -> None: ...
        def setDeceleration(self, deceleration: float, /) -> None: ...
        def setScale(self, scale: float, /) -> None: ...

    class QInputAspect(PySide6.Qt3DCore.Qt3DCore.QAbstractAspect):

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

        def availablePhysicalDevices(self, /) -> typing.List[str]: ...
        def createPhysicalDevice(self, name: str, /) -> PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice: ...

    class QInputChord(PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput):

        timeoutChanged           : typing.ClassVar[Signal] = ... # timeoutChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, timeout: int | None = ...) -> None: ...

        def addChord(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...
        def chords(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput]: ...
        def removeChord(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...
        def setTimeout(self, timeout: int, /) -> None: ...
        def timeout(self, /) -> int: ...

    class QInputSequence(PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput):

        buttonIntervalChanged    : typing.ClassVar[Signal] = ... # buttonIntervalChanged(int)
        timeoutChanged           : typing.ClassVar[Signal] = ... # timeoutChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, timeout: int | None = ..., buttonInterval: int | None = ...) -> None: ...

        def addSequence(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...
        def buttonInterval(self, /) -> int: ...
        def removeSequence(self, input: PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput, /) -> None: ...
        def sequences(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAbstractActionInput]: ...
        def setButtonInterval(self, buttonInterval: int, /) -> None: ...
        def setTimeout(self, timeout: int, /) -> None: ...
        def timeout(self, /) -> int: ...

    class QInputSettings(PySide6.Qt3DCore.Qt3DCore.QComponent):

        eventSourceChanged       : typing.ClassVar[Signal] = ... # eventSourceChanged(QObject*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, eventSource: PySide6.QtCore.QObject | None = ...) -> None: ...

        def eventSource(self, /) -> PySide6.QtCore.QObject: ...
        def setEventSource(self, eventSource: PySide6.QtCore.QObject, /) -> None: ...

    class QKeyEvent(PySide6.QtCore.QObject):

        @typing.overload
        def __init__(self, type: PySide6.QtCore.QEvent.Type, key: int, modifiers: PySide6.QtCore.Qt.KeyboardModifier, /, text: str = ..., autorep: bool = ..., count: int = ..., *, isAutoRepeat: bool | None = ..., nativeScanCode: int | None = ..., accepted: bool | None = ...) -> None: ...
        @typing.overload
        def __init__(self, ke: PySide6.QtGui.QKeyEvent, /, *, key: int | None = ..., text: str | None = ..., modifiers: int | None = ..., isAutoRepeat: bool | None = ..., count: int | None = ..., nativeScanCode: int | None = ..., accepted: bool | None = ...) -> None: ...

        def count(self, /) -> int: ...
        def isAccepted(self, /) -> bool: ...
        def isAutoRepeat(self, /) -> bool: ...
        def key(self, /) -> int: ...
        def matches(self, key_: PySide6.QtGui.QKeySequence.StandardKey, /) -> bool: ...
        def modifiers(self, /) -> int: ...
        def nativeScanCode(self, /) -> int: ...
        def setAccepted(self, accepted: bool, /) -> None: ...
        def text(self, /) -> str: ...
        def type(self, /) -> PySide6.QtCore.QEvent.Type: ...

    class QKeyboardDevice(PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice):

        activeInputChanged       : typing.ClassVar[Signal] = ... # activeInputChanged(QKeyboardHandler*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, activeInput: PySide6.Qt3DInput.Qt3DInput.QKeyboardHandler | None = ...) -> None: ...

        def activeInput(self, /) -> PySide6.Qt3DInput.Qt3DInput.QKeyboardHandler: ...
        def axisCount(self, /) -> int: ...
        def axisIdentifier(self, name: str, /) -> int: ...
        def axisNames(self, /) -> typing.List[str]: ...
        def buttonCount(self, /) -> int: ...
        def buttonIdentifier(self, name: str, /) -> int: ...
        def buttonNames(self, /) -> typing.List[str]: ...

    class QKeyboardHandler(PySide6.Qt3DCore.Qt3DCore.QComponent):

        asteriskPressed          : typing.ClassVar[Signal] = ... # asteriskPressed(Qt3DInput::QKeyEvent*)
        backPressed              : typing.ClassVar[Signal] = ... # backPressed(Qt3DInput::QKeyEvent*)
        backtabPressed           : typing.ClassVar[Signal] = ... # backtabPressed(Qt3DInput::QKeyEvent*)
        callPressed              : typing.ClassVar[Signal] = ... # callPressed(Qt3DInput::QKeyEvent*)
        cancelPressed            : typing.ClassVar[Signal] = ... # cancelPressed(Qt3DInput::QKeyEvent*)
        context1Pressed          : typing.ClassVar[Signal] = ... # context1Pressed(Qt3DInput::QKeyEvent*)
        context2Pressed          : typing.ClassVar[Signal] = ... # context2Pressed(Qt3DInput::QKeyEvent*)
        context3Pressed          : typing.ClassVar[Signal] = ... # context3Pressed(Qt3DInput::QKeyEvent*)
        context4Pressed          : typing.ClassVar[Signal] = ... # context4Pressed(Qt3DInput::QKeyEvent*)
        deletePressed            : typing.ClassVar[Signal] = ... # deletePressed(Qt3DInput::QKeyEvent*)
        digit0Pressed            : typing.ClassVar[Signal] = ... # digit0Pressed(Qt3DInput::QKeyEvent*)
        digit1Pressed            : typing.ClassVar[Signal] = ... # digit1Pressed(Qt3DInput::QKeyEvent*)
        digit2Pressed            : typing.ClassVar[Signal] = ... # digit2Pressed(Qt3DInput::QKeyEvent*)
        digit3Pressed            : typing.ClassVar[Signal] = ... # digit3Pressed(Qt3DInput::QKeyEvent*)
        digit4Pressed            : typing.ClassVar[Signal] = ... # digit4Pressed(Qt3DInput::QKeyEvent*)
        digit5Pressed            : typing.ClassVar[Signal] = ... # digit5Pressed(Qt3DInput::QKeyEvent*)
        digit6Pressed            : typing.ClassVar[Signal] = ... # digit6Pressed(Qt3DInput::QKeyEvent*)
        digit7Pressed            : typing.ClassVar[Signal] = ... # digit7Pressed(Qt3DInput::QKeyEvent*)
        digit8Pressed            : typing.ClassVar[Signal] = ... # digit8Pressed(Qt3DInput::QKeyEvent*)
        digit9Pressed            : typing.ClassVar[Signal] = ... # digit9Pressed(Qt3DInput::QKeyEvent*)
        downPressed              : typing.ClassVar[Signal] = ... # downPressed(Qt3DInput::QKeyEvent*)
        enterPressed             : typing.ClassVar[Signal] = ... # enterPressed(Qt3DInput::QKeyEvent*)
        escapePressed            : typing.ClassVar[Signal] = ... # escapePressed(Qt3DInput::QKeyEvent*)
        flipPressed              : typing.ClassVar[Signal] = ... # flipPressed(Qt3DInput::QKeyEvent*)
        focusChanged             : typing.ClassVar[Signal] = ... # focusChanged(bool)
        hangupPressed            : typing.ClassVar[Signal] = ... # hangupPressed(Qt3DInput::QKeyEvent*)
        leftPressed              : typing.ClassVar[Signal] = ... # leftPressed(Qt3DInput::QKeyEvent*)
        menuPressed              : typing.ClassVar[Signal] = ... # menuPressed(Qt3DInput::QKeyEvent*)
        noPressed                : typing.ClassVar[Signal] = ... # noPressed(Qt3DInput::QKeyEvent*)
        numberSignPressed        : typing.ClassVar[Signal] = ... # numberSignPressed(Qt3DInput::QKeyEvent*)
        pressed                  : typing.ClassVar[Signal] = ... # pressed(Qt3DInput::QKeyEvent*)
        released                 : typing.ClassVar[Signal] = ... # released(Qt3DInput::QKeyEvent*)
        returnPressed            : typing.ClassVar[Signal] = ... # returnPressed(Qt3DInput::QKeyEvent*)
        rightPressed             : typing.ClassVar[Signal] = ... # rightPressed(Qt3DInput::QKeyEvent*)
        selectPressed            : typing.ClassVar[Signal] = ... # selectPressed(Qt3DInput::QKeyEvent*)
        sourceDeviceChanged      : typing.ClassVar[Signal] = ... # sourceDeviceChanged(QKeyboardDevice*)
        spacePressed             : typing.ClassVar[Signal] = ... # spacePressed(Qt3DInput::QKeyEvent*)
        tabPressed               : typing.ClassVar[Signal] = ... # tabPressed(Qt3DInput::QKeyEvent*)
        upPressed                : typing.ClassVar[Signal] = ... # upPressed(Qt3DInput::QKeyEvent*)
        volumeDownPressed        : typing.ClassVar[Signal] = ... # volumeDownPressed(Qt3DInput::QKeyEvent*)
        volumeUpPressed          : typing.ClassVar[Signal] = ... # volumeUpPressed(Qt3DInput::QKeyEvent*)
        yesPressed               : typing.ClassVar[Signal] = ... # yesPressed(Qt3DInput::QKeyEvent*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sourceDevice: PySide6.Qt3DInput.Qt3DInput.QKeyboardDevice | None = ..., focus: bool | None = ...) -> None: ...

        def focus(self, /) -> bool: ...
        def setFocus(self, focus: bool, /) -> None: ...
        def setSourceDevice(self, keyboardDevice: PySide6.Qt3DInput.Qt3DInput.QKeyboardDevice, /) -> None: ...
        def sourceDevice(self, /) -> PySide6.Qt3DInput.Qt3DInput.QKeyboardDevice: ...

    class QLogicalDevice(PySide6.Qt3DCore.Qt3DCore.QComponent):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...

        def actions(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAction]: ...
        def addAction(self, action: PySide6.Qt3DInput.Qt3DInput.QAction, /) -> None: ...
        def addAxis(self, axis: PySide6.Qt3DInput.Qt3DInput.QAxis, /) -> None: ...
        def axes(self, /) -> typing.List[PySide6.Qt3DInput.Qt3DInput.QAxis]: ...
        def removeAction(self, action: PySide6.Qt3DInput.Qt3DInput.QAction, /) -> None: ...
        def removeAxis(self, axis: PySide6.Qt3DInput.Qt3DInput.QAxis, /) -> None: ...

    class QMouseDevice(PySide6.Qt3DInput.Qt3DInput.QAbstractPhysicalDevice):

        sensitivityChanged       : typing.ClassVar[Signal] = ... # sensitivityChanged(float)
        updateAxesContinuouslyChanged: typing.ClassVar[Signal] = ... # updateAxesContinuouslyChanged(bool)

        class Axis(enum.Enum):

            X                         = 0x0
            Y                         = 0x1
            WheelX                    = 0x2
            WheelY                    = 0x3


        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sensitivity: float | None = ..., updateAxesContinuously: bool | None = ...) -> None: ...

        def axisCount(self, /) -> int: ...
        def axisIdentifier(self, name: str, /) -> int: ...
        def axisNames(self, /) -> typing.List[str]: ...
        def buttonCount(self, /) -> int: ...
        def buttonIdentifier(self, name: str, /) -> int: ...
        def buttonNames(self, /) -> typing.List[str]: ...
        def sensitivity(self, /) -> float: ...
        def setSensitivity(self, value: float, /) -> None: ...
        def setUpdateAxesContinuously(self, updateAxesContinuously: bool, /) -> None: ...
        def updateAxesContinuously(self, /) -> bool: ...

    class QMouseEvent(PySide6.QtCore.QObject):

        class Buttons(enum.Enum):

            NoButton                  = 0x0
            LeftButton                = 0x1
            RightButton               = 0x2
            MiddleButton              = 0x4
            BackButton                = 0x8

        class Modifiers(enum.Enum):

            NoModifier                = 0x0
            ShiftModifier             = 0x2000000
            ControlModifier           = 0x4000000
            AltModifier               = 0x8000000
            MetaModifier              = 0x10000000
            KeypadModifier            = 0x20000000


        def __init__(self, e: PySide6.QtGui.QMouseEvent, /, *, x: int | None = ..., y: int | None = ..., wasHeld: bool | None = ..., button: PySide6.Qt3DInput.Qt3DInput.QMouseEvent.Buttons | None = ..., buttons: int | None = ..., modifiers: PySide6.Qt3DInput.Qt3DInput.QMouseEvent.Modifiers | None = ..., accepted: bool | None = ...) -> None: ...

        def button(self, /) -> PySide6.Qt3DInput.Qt3DInput.QMouseEvent.Buttons: ...
        def buttons(self, /) -> int: ...
        def isAccepted(self, /) -> bool: ...
        def modifiers(self, /) -> PySide6.Qt3DInput.Qt3DInput.QMouseEvent.Modifiers: ...
        def setAccepted(self, accepted: bool, /) -> None: ...
        def type(self, /) -> PySide6.QtCore.QEvent.Type: ...
        def wasHeld(self, /) -> bool: ...
        def x(self, /) -> int: ...
        def y(self, /) -> int: ...

    class QMouseHandler(PySide6.Qt3DCore.Qt3DCore.QComponent):

        clicked                  : typing.ClassVar[Signal] = ... # clicked(Qt3DInput::QMouseEvent*)
        containsMouseChanged     : typing.ClassVar[Signal] = ... # containsMouseChanged(bool)
        doubleClicked            : typing.ClassVar[Signal] = ... # doubleClicked(Qt3DInput::QMouseEvent*)
        entered                  : typing.ClassVar[Signal] = ... # entered()
        exited                   : typing.ClassVar[Signal] = ... # exited()
        positionChanged          : typing.ClassVar[Signal] = ... # positionChanged(Qt3DInput::QMouseEvent*)
        pressAndHold             : typing.ClassVar[Signal] = ... # pressAndHold(Qt3DInput::QMouseEvent*)
        pressed                  : typing.ClassVar[Signal] = ... # pressed(Qt3DInput::QMouseEvent*)
        released                 : typing.ClassVar[Signal] = ... # released(Qt3DInput::QMouseEvent*)
        sourceDeviceChanged      : typing.ClassVar[Signal] = ... # sourceDeviceChanged(QMouseDevice*)
        wheel                    : typing.ClassVar[Signal] = ... # wheel(Qt3DInput::QWheelEvent*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sourceDevice: PySide6.Qt3DInput.Qt3DInput.QMouseDevice | None = ..., containsMouse: bool | None = ...) -> None: ...

        def containsMouse(self, /) -> bool: ...
        def setContainsMouse(self, contains: bool, /) -> None: ...
        def setSourceDevice(self, mouseDevice: PySide6.Qt3DInput.Qt3DInput.QMouseDevice, /) -> None: ...
        def sourceDevice(self, /) -> PySide6.Qt3DInput.Qt3DInput.QMouseDevice: ...

    class QWheelEvent(PySide6.QtCore.QObject):

        class Buttons(enum.Enum):

            NoButton                  = 0x0
            LeftButton                = 0x1
            RightButton               = 0x2
            MiddleButton              = 0x4
            BackButton                = 0x8

        class Modifiers(enum.Enum):

            NoModifier                = 0x0
            ShiftModifier             = 0x2000000
            ControlModifier           = 0x4000000
            AltModifier               = 0x8000000
            MetaModifier              = 0x10000000
            KeypadModifier            = 0x20000000


        def __init__(self, e: PySide6.QtGui.QWheelEvent, /, *, x: int | None = ..., y: int | None = ..., angleDelta: PySide6.QtCore.QPoint | None = ..., buttons: int | None = ..., modifiers: PySide6.Qt3DInput.Qt3DInput.QWheelEvent.Modifiers | None = ..., accepted: bool | None = ...) -> None: ...

        def angleDelta(self, /) -> PySide6.QtCore.QPoint: ...
        def buttons(self, /) -> int: ...
        def isAccepted(self, /) -> bool: ...
        def modifiers(self, /) -> PySide6.Qt3DInput.Qt3DInput.QWheelEvent.Modifiers: ...
        def setAccepted(self, accepted: bool, /) -> None: ...
        def type(self, /) -> PySide6.QtCore.QEvent.Type: ...
        def x(self, /) -> int: ...
        def y(self, /) -> int: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtLocation, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtLocation`

import PySide6.QtLocation
import PySide6.QtCore
import PySide6.QtPositioning

import os
import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QGeoCodeReply(PySide6.QtCore.QObject):

    aborted                  : typing.ClassVar[Signal] = ... # aborted()
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoCodeReply::Error,QString); errorOccurred(QGeoCodeReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished()

    class Error(enum.Enum):

        NoError                   = 0x0
        EngineNotSetError         = 0x1
        CommunicationError        = 0x2
        ParseError                = 0x3
        UnsupportedOptionError    = 0x4
        CombinationError          = 0x5
        UnknownError              = 0x6


    @typing.overload
    def __init__(self, error: PySide6.QtLocation.QGeoCodeReply.Error, errorString: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def abort(self, /) -> None: ...
    def addLocation(self, location: PySide6.QtPositioning.QGeoLocation, /) -> None: ...
    def error(self, /) -> PySide6.QtLocation.QGeoCodeReply.Error: ...
    def errorString(self, /) -> str: ...
    def isFinished(self, /) -> bool: ...
    def limit(self, /) -> int: ...
    def locations(self, /) -> typing.List[PySide6.QtPositioning.QGeoLocation]: ...
    def offset(self, /) -> int: ...
    def setError(self, error: PySide6.QtLocation.QGeoCodeReply.Error, errorString: str, /) -> None: ...
    def setFinished(self, finished: bool, /) -> None: ...
    def setLimit(self, limit: int, /) -> None: ...
    def setLocations(self, locations: collections.abc.Sequence[PySide6.QtPositioning.QGeoLocation], /) -> None: ...
    def setOffset(self, offset: int, /) -> None: ...
    def setViewport(self, viewport: PySide6.QtPositioning.QGeoShape, /) -> None: ...
    def viewport(self, /) -> PySide6.QtPositioning.QGeoShape: ...


class QGeoCodingManager(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoCodeReply*,QGeoCodeReply::Error,QString); errorOccurred(QGeoCodeReply*,QGeoCodeReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QGeoCodeReply*)
    @typing.overload
    def geocode(self, address: PySide6.QtPositioning.QGeoAddress, /, bounds: PySide6.QtPositioning.QGeoShape = ...) -> PySide6.QtLocation.QGeoCodeReply: ...
    @typing.overload
    def geocode(self, searchString: str, /, limit: int = ..., offset: int | None = ..., bounds: PySide6.QtPositioning.QGeoShape = ...) -> PySide6.QtLocation.QGeoCodeReply: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def reverseGeocode(self, coordinate: PySide6.QtPositioning.QGeoCoordinate, /, bounds: PySide6.QtPositioning.QGeoShape = ...) -> PySide6.QtLocation.QGeoCodeReply: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...


class QGeoCodingManagerEngine(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoCodeReply*,QGeoCodeReply::Error,QString); errorOccurred(QGeoCodeReply*,QGeoCodeReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QGeoCodeReply*)

    def __init__(self, parameters: typing.Dict[str, typing.Any], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    @typing.overload
    def geocode(self, address: PySide6.QtPositioning.QGeoAddress, bounds: PySide6.QtPositioning.QGeoShape, /) -> PySide6.QtLocation.QGeoCodeReply: ...
    @typing.overload
    def geocode(self, address: str, limit: int, offset: int, bounds: PySide6.QtPositioning.QGeoShape, /) -> PySide6.QtLocation.QGeoCodeReply: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def reverseGeocode(self, coordinate: PySide6.QtPositioning.QGeoCoordinate, bounds: PySide6.QtPositioning.QGeoShape, /) -> PySide6.QtLocation.QGeoCodeReply: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...


class QGeoManeuver(Shiboken.Object):

    class InstructionDirection(enum.Enum):

        NoDirection               = 0x0
        DirectionForward          = 0x1
        DirectionBearRight        = 0x2
        DirectionLightRight       = 0x3
        DirectionRight            = 0x4
        DirectionHardRight        = 0x5
        DirectionUTurnRight       = 0x6
        DirectionUTurnLeft        = 0x7
        DirectionHardLeft         = 0x8
        DirectionLeft             = 0x9
        DirectionLightLeft        = 0xa
        DirectionBearLeft         = 0xb


    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QGeoManeuver, /, *, valid: bool | None = ..., position: PySide6.QtPositioning.QGeoCoordinate | None = ..., instructionText: str | None = ..., direction: PySide6.QtLocation.QGeoManeuver.InstructionDirection | None = ..., timeToNextInstruction: int | None = ..., distanceToNextInstruction: float | None = ..., waypoint: PySide6.QtPositioning.QGeoCoordinate | None = ..., extendedAttributes: typing.Dict[str, typing.Any] | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, valid: bool | None = ..., position: PySide6.QtPositioning.QGeoCoordinate | None = ..., instructionText: str | None = ..., direction: PySide6.QtLocation.QGeoManeuver.InstructionDirection | None = ..., timeToNextInstruction: int | None = ..., distanceToNextInstruction: float | None = ..., waypoint: PySide6.QtPositioning.QGeoCoordinate | None = ..., extendedAttributes: typing.Dict[str, typing.Any] | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QGeoManeuver, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QGeoManeuver, /) -> bool: ...
    def direction(self, /) -> PySide6.QtLocation.QGeoManeuver.InstructionDirection: ...
    def distanceToNextInstruction(self, /) -> float: ...
    def extendedAttributes(self, /) -> typing.Dict[str, typing.Any]: ...
    def instructionText(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def position(self, /) -> PySide6.QtPositioning.QGeoCoordinate: ...
    def setDirection(self, direction: PySide6.QtLocation.QGeoManeuver.InstructionDirection, /) -> None: ...
    def setDistanceToNextInstruction(self, distance: float, /) -> None: ...
    def setExtendedAttributes(self, extendedAttributes: typing.Dict[str, typing.Any], /) -> None: ...
    def setInstructionText(self, instructionText: str, /) -> None: ...
    def setPosition(self, position: PySide6.QtPositioning.QGeoCoordinate, /) -> None: ...
    def setTimeToNextInstruction(self, secs: int, /) -> None: ...
    def setWaypoint(self, coordinate: PySide6.QtPositioning.QGeoCoordinate, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QGeoManeuver, /) -> None: ...
    def timeToNextInstruction(self, /) -> int: ...
    def waypoint(self, /) -> PySide6.QtPositioning.QGeoCoordinate: ...


class QGeoRoute(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QGeoRoute, /, *, routeId: str | None = ..., bounds: PySide6.QtPositioning.QGeoRectangle | None = ..., travelTime: int | None = ..., distance: float | None = ..., path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate] | None = ..., routeLegs: collections.abc.Sequence[PySide6.QtLocation.QGeoRoute] | None = ..., extendedAttributes: typing.Dict[str, typing.Any] | None = ..., legIndex: int | None = ..., overallRoute: PySide6.QtLocation.QGeoRoute | None = ..., segmentsCount: int | None = ..., segments: collections.abc.Sequence[PySide6.QtLocation.QGeoRouteSegment] | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, routeId: str | None = ..., bounds: PySide6.QtPositioning.QGeoRectangle | None = ..., travelTime: int | None = ..., distance: float | None = ..., path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate] | None = ..., routeLegs: collections.abc.Sequence[PySide6.QtLocation.QGeoRoute] | None = ..., extendedAttributes: typing.Dict[str, typing.Any] | None = ..., legIndex: int | None = ..., overallRoute: PySide6.QtLocation.QGeoRoute | None = ..., segmentsCount: int | None = ..., segments: collections.abc.Sequence[PySide6.QtLocation.QGeoRouteSegment] | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QGeoRoute, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QGeoRoute, /) -> bool: ...
    def bounds(self, /) -> PySide6.QtPositioning.QGeoRectangle: ...
    def distance(self, /) -> float: ...
    def extendedAttributes(self, /) -> typing.Dict[str, typing.Any]: ...
    def firstRouteSegment(self, /) -> PySide6.QtLocation.QGeoRouteSegment: ...
    def legIndex(self, /) -> int: ...
    def overallRoute(self, /) -> PySide6.QtLocation.QGeoRoute: ...
    def path(self, /) -> typing.List[PySide6.QtPositioning.QGeoCoordinate]: ...
    def request(self, /) -> PySide6.QtLocation.QGeoRouteRequest: ...
    def routeId(self, /) -> str: ...
    def routeLegs(self, /) -> typing.List[PySide6.QtLocation.QGeoRoute]: ...
    def segments(self, /) -> typing.List[PySide6.QtLocation.QGeoRouteSegment]: ...
    def segmentsCount(self, /) -> int: ...
    def setBounds(self, bounds: PySide6.QtPositioning.QGeoRectangle | PySide6.QtPositioning.QGeoShape | collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate], /) -> None: ...
    def setDistance(self, distance: float, /) -> None: ...
    def setExtendedAttributes(self, extendedAttributes: typing.Dict[str, typing.Any], /) -> None: ...
    def setFirstRouteSegment(self, routeSegment: PySide6.QtLocation.QGeoRouteSegment, /) -> None: ...
    def setLegIndex(self, idx: int, /) -> None: ...
    def setOverallRoute(self, route: PySide6.QtLocation.QGeoRoute, /) -> None: ...
    def setPath(self, path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate], /) -> None: ...
    def setRequest(self, request: PySide6.QtLocation.QGeoRouteRequest, /) -> None: ...
    def setRouteId(self, id: str, /) -> None: ...
    def setRouteLegs(self, legs: collections.abc.Sequence[PySide6.QtLocation.QGeoRoute], /) -> None: ...
    def setTravelMode(self, mode: PySide6.QtLocation.QGeoRouteRequest.TravelMode, /) -> None: ...
    def setTravelTime(self, secs: int, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QGeoRoute, /) -> None: ...
    def travelMode(self, /) -> PySide6.QtLocation.QGeoRouteRequest.TravelMode: ...
    def travelTime(self, /) -> int: ...


class QGeoRouteReply(PySide6.QtCore.QObject):

    aborted                  : typing.ClassVar[Signal] = ... # aborted()
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoRouteReply::Error,QString); errorOccurred(QGeoRouteReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished()

    class Error(enum.Enum):

        NoError                   = 0x0
        EngineNotSetError         = 0x1
        CommunicationError        = 0x2
        ParseError                = 0x3
        UnsupportedOptionError    = 0x4
        UnknownError              = 0x5


    @typing.overload
    def __init__(self, error: PySide6.QtLocation.QGeoRouteReply.Error, errorString: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, request: PySide6.QtLocation.QGeoRouteRequest, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def abort(self, /) -> None: ...
    def addRoutes(self, routes: collections.abc.Sequence[PySide6.QtLocation.QGeoRoute], /) -> None: ...
    def error(self, /) -> PySide6.QtLocation.QGeoRouteReply.Error: ...
    def errorString(self, /) -> str: ...
    def isFinished(self, /) -> bool: ...
    def request(self, /) -> PySide6.QtLocation.QGeoRouteRequest: ...
    def routes(self, /) -> typing.List[PySide6.QtLocation.QGeoRoute]: ...
    def setError(self, error: PySide6.QtLocation.QGeoRouteReply.Error, errorString: str, /) -> None: ...
    def setFinished(self, finished: bool, /) -> None: ...
    def setRoutes(self, routes: collections.abc.Sequence[PySide6.QtLocation.QGeoRoute], /) -> None: ...


class QGeoRouteRequest(Shiboken.Object):

    class FeatureType(enum.Flag):

        NoFeature                 = 0x0
        TollFeature               = 0x1
        HighwayFeature            = 0x2
        PublicTransitFeature      = 0x4
        FerryFeature              = 0x8
        TunnelFeature             = 0x10
        DirtRoadFeature           = 0x20
        ParksFeature              = 0x40
        MotorPoolLaneFeature      = 0x80
        TrafficFeature            = 0x100

    class FeatureWeight(enum.Flag):

        NeutralFeatureWeight      = 0x0
        PreferFeatureWeight       = 0x1
        RequireFeatureWeight      = 0x2
        AvoidFeatureWeight        = 0x4
        DisallowFeatureWeight     = 0x8

    class ManeuverDetail(enum.Flag):

        NoManeuvers               = 0x0
        BasicManeuvers            = 0x1

    class RouteOptimization(enum.Flag):

        ShortestRoute             = 0x1
        FastestRoute              = 0x2
        MostEconomicRoute         = 0x4
        MostScenicRoute           = 0x8

    class SegmentDetail(enum.Flag):

        NoSegmentData             = 0x0
        BasicSegmentData          = 0x1

    class TravelMode(enum.Flag):

        CarTravel                 = 0x1
        PedestrianTravel          = 0x2
        BicycleTravel             = 0x4
        PublicTransitTravel       = 0x8
        TruckTravel               = 0x10


    @typing.overload
    def __init__(self, origin: PySide6.QtPositioning.QGeoCoordinate, destination: PySide6.QtPositioning.QGeoCoordinate, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QGeoRouteRequest, /) -> None: ...
    @typing.overload
    def __init__(self, /, waypoints: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate] = ...) -> None: ...

    def __eq__(self, rhs: PySide6.QtLocation.QGeoRouteRequest, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QGeoRouteRequest, /) -> bool: ...
    def departureTime(self, /) -> PySide6.QtCore.QDateTime: ...
    def excludeAreas(self, /) -> typing.List[PySide6.QtPositioning.QGeoRectangle]: ...
    def featureTypes(self, /) -> typing.List[PySide6.QtLocation.QGeoRouteRequest.FeatureType]: ...
    def featureWeight(self, featureType: PySide6.QtLocation.QGeoRouteRequest.FeatureType, /) -> PySide6.QtLocation.QGeoRouteRequest.FeatureWeight: ...
    def maneuverDetail(self, /) -> PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail: ...
    def numberAlternativeRoutes(self, /) -> int: ...
    def routeOptimization(self, /) -> PySide6.QtLocation.QGeoRouteRequest.RouteOptimization: ...
    def segmentDetail(self, /) -> PySide6.QtLocation.QGeoRouteRequest.SegmentDetail: ...
    def setDepartureTime(self, departureTime: PySide6.QtCore.QDateTime, /) -> None: ...
    def setExcludeAreas(self, areas: collections.abc.Sequence[PySide6.QtPositioning.QGeoRectangle], /) -> None: ...
    def setFeatureWeight(self, featureType: PySide6.QtLocation.QGeoRouteRequest.FeatureType, featureWeight: PySide6.QtLocation.QGeoRouteRequest.FeatureWeight, /) -> None: ...
    def setManeuverDetail(self, maneuverDetail: PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail, /) -> None: ...
    def setNumberAlternativeRoutes(self, alternatives: int, /) -> None: ...
    def setRouteOptimization(self, optimization: PySide6.QtLocation.QGeoRouteRequest.RouteOptimization, /) -> None: ...
    def setSegmentDetail(self, segmentDetail: PySide6.QtLocation.QGeoRouteRequest.SegmentDetail, /) -> None: ...
    def setTravelModes(self, travelModes: PySide6.QtLocation.QGeoRouteRequest.TravelMode, /) -> None: ...
    def setWaypoints(self, waypoints: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate], /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QGeoRouteRequest, /) -> None: ...
    def travelModes(self, /) -> PySide6.QtLocation.QGeoRouteRequest.TravelMode: ...
    def waypoints(self, /) -> typing.List[PySide6.QtPositioning.QGeoCoordinate]: ...


class QGeoRouteSegment(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QGeoRouteSegment, /, *, travelTime: int | None = ..., distance: float | None = ..., path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate] | None = ..., maneuver: PySide6.QtLocation.QGeoManeuver | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, travelTime: int | None = ..., distance: float | None = ..., path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate] | None = ..., maneuver: PySide6.QtLocation.QGeoManeuver | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QGeoRouteSegment, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QGeoRouteSegment, /) -> bool: ...
    def distance(self, /) -> float: ...
    def isLegLastSegment(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def maneuver(self, /) -> PySide6.QtLocation.QGeoManeuver: ...
    def nextRouteSegment(self, /) -> PySide6.QtLocation.QGeoRouteSegment: ...
    def path(self, /) -> typing.List[PySide6.QtPositioning.QGeoCoordinate]: ...
    def setDistance(self, distance: float, /) -> None: ...
    def setManeuver(self, maneuver: PySide6.QtLocation.QGeoManeuver, /) -> None: ...
    def setNextRouteSegment(self, routeSegment: PySide6.QtLocation.QGeoRouteSegment, /) -> None: ...
    def setPath(self, path: collections.abc.Sequence[PySide6.QtPositioning.QGeoCoordinate], /) -> None: ...
    def setTravelTime(self, secs: int, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QGeoRouteSegment, /) -> None: ...
    def travelTime(self, /) -> int: ...


class QGeoRoutingManager(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoRouteReply*,QGeoRouteReply::Error,QString); errorOccurred(QGeoRouteReply*,QGeoRouteReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QGeoRouteReply*)
    def calculateRoute(self, request: PySide6.QtLocation.QGeoRouteRequest, /) -> PySide6.QtLocation.QGeoRouteReply: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def measurementSystem(self, /) -> PySide6.QtCore.QLocale.MeasurementSystem: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setMeasurementSystem(self, system: PySide6.QtCore.QLocale.MeasurementSystem, /) -> None: ...
    def supportedFeatureTypes(self, /) -> PySide6.QtLocation.QGeoRouteRequest.FeatureType: ...
    def supportedFeatureWeights(self, /) -> PySide6.QtLocation.QGeoRouteRequest.FeatureWeight: ...
    def supportedManeuverDetails(self, /) -> PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail: ...
    def supportedRouteOptimizations(self, /) -> PySide6.QtLocation.QGeoRouteRequest.RouteOptimization: ...
    def supportedSegmentDetails(self, /) -> PySide6.QtLocation.QGeoRouteRequest.SegmentDetail: ...
    def supportedTravelModes(self, /) -> PySide6.QtLocation.QGeoRouteRequest.TravelMode: ...
    def updateRoute(self, route: PySide6.QtLocation.QGeoRoute, position: PySide6.QtPositioning.QGeoCoordinate, /) -> PySide6.QtLocation.QGeoRouteReply: ...


class QGeoRoutingManagerEngine(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QGeoRouteReply*,QGeoRouteReply::Error,QString); errorOccurred(QGeoRouteReply*,QGeoRouteReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QGeoRouteReply*)

    def __init__(self, parameters: typing.Dict[str, typing.Any], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def calculateRoute(self, request: PySide6.QtLocation.QGeoRouteRequest, /) -> PySide6.QtLocation.QGeoRouteReply: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def measurementSystem(self, /) -> PySide6.QtCore.QLocale.MeasurementSystem: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setMeasurementSystem(self, system: PySide6.QtCore.QLocale.MeasurementSystem, /) -> None: ...
    def setSupportedFeatureTypes(self, featureTypes: PySide6.QtLocation.QGeoRouteRequest.FeatureType, /) -> None: ...
    def setSupportedFeatureWeights(self, featureWeights: PySide6.QtLocation.QGeoRouteRequest.FeatureWeight, /) -> None: ...
    def setSupportedManeuverDetails(self, maneuverDetails: PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail, /) -> None: ...
    def setSupportedRouteOptimizations(self, optimizations: PySide6.QtLocation.QGeoRouteRequest.RouteOptimization, /) -> None: ...
    def setSupportedSegmentDetails(self, segmentDetails: PySide6.QtLocation.QGeoRouteRequest.SegmentDetail, /) -> None: ...
    def setSupportedTravelModes(self, travelModes: PySide6.QtLocation.QGeoRouteRequest.TravelMode, /) -> None: ...
    def supportedFeatureTypes(self, /) -> PySide6.QtLocation.QGeoRouteRequest.FeatureType: ...
    def supportedFeatureWeights(self, /) -> PySide6.QtLocation.QGeoRouteRequest.FeatureWeight: ...
    def supportedManeuverDetails(self, /) -> PySide6.QtLocation.QGeoRouteRequest.ManeuverDetail: ...
    def supportedRouteOptimizations(self, /) -> PySide6.QtLocation.QGeoRouteRequest.RouteOptimization: ...
    def supportedSegmentDetails(self, /) -> PySide6.QtLocation.QGeoRouteRequest.SegmentDetail: ...
    def supportedTravelModes(self, /) -> PySide6.QtLocation.QGeoRouteRequest.TravelMode: ...
    def updateRoute(self, route: PySide6.QtLocation.QGeoRoute, position: PySide6.QtPositioning.QGeoCoordinate, /) -> PySide6.QtLocation.QGeoRouteReply: ...


class QGeoServiceProvider(PySide6.QtCore.QObject):

    class Error(enum.Enum):

        NoError                   = 0x0
        NotSupportedError         = 0x1
        UnknownParameterError     = 0x2
        MissingRequiredParameterError = 0x3
        ConnectionError           = 0x4
        LoaderError               = 0x5

    class GeocodingFeature(enum.Flag):

        AnyGeocodingFeatures      = -1
        NoGeocodingFeatures       = 0x0
        OnlineGeocodingFeature    = 0x1
        OfflineGeocodingFeature   = 0x2
        ReverseGeocodingFeature   = 0x4
        LocalizedGeocodingFeature = 0x8

    class MappingFeature(enum.Flag):

        AnyMappingFeatures        = -1
        NoMappingFeatures         = 0x0
        OnlineMappingFeature      = 0x1
        OfflineMappingFeature     = 0x2
        LocalizedMappingFeature   = 0x4

    class NavigationFeature(enum.Flag):

        AnyNavigationFeatures     = -1
        NoNavigationFeatures      = 0x0
        OnlineNavigationFeature   = 0x1
        OfflineNavigationFeature  = 0x2

    class PlacesFeature(enum.Flag):

        AnyPlacesFeatures         = -1
        NoPlacesFeatures          = 0x0
        OnlinePlacesFeature       = 0x1
        OfflinePlacesFeature      = 0x2
        SavePlaceFeature          = 0x4
        RemovePlaceFeature        = 0x8
        SaveCategoryFeature       = 0x10
        RemoveCategoryFeature     = 0x20
        PlaceRecommendationsFeature = 0x40
        SearchSuggestionsFeature  = 0x80
        LocalizedPlacesFeature    = 0x100
        NotificationsFeature      = 0x200
        PlaceMatchingFeature      = 0x400

    class RoutingFeature(enum.Flag):

        AnyRoutingFeatures        = -1
        NoRoutingFeatures         = 0x0
        OnlineRoutingFeature      = 0x1
        OfflineRoutingFeature     = 0x2
        LocalizedRoutingFeature   = 0x4
        RouteUpdatesFeature       = 0x8
        AlternativeRoutesFeature  = 0x10
        ExcludeAreasRoutingFeature = 0x20


    def __init__(self, providerName: str, /, parameters: typing.Dict[str, typing.Any] = ..., allowExperimental: bool = ...) -> None: ...

    @staticmethod
    def availableServiceProviders() -> typing.List[str]: ...
    def error(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def errorString(self, /) -> str: ...
    def geocodingError(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def geocodingErrorString(self, /) -> str: ...
    def geocodingFeatures(self, /) -> PySide6.QtLocation.QGeoServiceProvider.GeocodingFeature: ...
    def geocodingManager(self, /) -> PySide6.QtLocation.QGeoCodingManager: ...
    def mappingError(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def mappingErrorString(self, /) -> str: ...
    def mappingFeatures(self, /) -> PySide6.QtLocation.QGeoServiceProvider.MappingFeature: ...
    def navigationError(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def navigationErrorString(self, /) -> str: ...
    def navigationFeatures(self, /) -> PySide6.QtLocation.QGeoServiceProvider.NavigationFeature: ...
    def placeManager(self, /) -> PySide6.QtLocation.QPlaceManager: ...
    def placesError(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def placesErrorString(self, /) -> str: ...
    def placesFeatures(self, /) -> PySide6.QtLocation.QGeoServiceProvider.PlacesFeature: ...
    def routingError(self, /) -> PySide6.QtLocation.QGeoServiceProvider.Error: ...
    def routingErrorString(self, /) -> str: ...
    def routingFeatures(self, /) -> PySide6.QtLocation.QGeoServiceProvider.RoutingFeature: ...
    def routingManager(self, /) -> PySide6.QtLocation.QGeoRoutingManager: ...
    def setAllowExperimental(self, allow: bool, /) -> None: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setParameters(self, parameters: typing.Dict[str, typing.Any], /) -> None: ...


class QGeoServiceProviderFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def createGeocodingManagerEngine(self, parameters: typing.Dict[str, typing.Any], error: PySide6.QtLocation.QGeoServiceProvider.Error, /) -> typing.Tuple[PySide6.QtLocation.QGeoCodingManagerEngine, str]: ...
    def createPlaceManagerEngine(self, parameters: typing.Dict[str, typing.Any], error: PySide6.QtLocation.QGeoServiceProvider.Error, /) -> typing.Tuple[PySide6.QtLocation.QPlaceManagerEngine, str]: ...
    def createRoutingManagerEngine(self, parameters: typing.Dict[str, typing.Any], error: PySide6.QtLocation.QGeoServiceProvider.Error, /) -> typing.Tuple[PySide6.QtLocation.QGeoRoutingManagerEngine, str]: ...


class QIntList: ...


class QLocation(Shiboken.Object):

    class Visibility(enum.Flag):

        UnspecifiedVisibility     = 0x0
        DeviceVisibility          = 0x1
        PrivateVisibility         = 0x2
        PublicVisibility          = 0x4


class QPlace(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlace, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlace, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlace, /) -> bool: ...
    def appendContactDetail(self, contactType: str, detail: PySide6.QtLocation.QPlaceContactDetail, /) -> None: ...
    def attribution(self, /) -> str: ...
    def categories(self, /) -> typing.List[PySide6.QtLocation.QPlaceCategory]: ...
    def contactDetails(self, contactType: str, /) -> typing.List[PySide6.QtLocation.QPlaceContactDetail]: ...
    def contactTypes(self, /) -> typing.List[str]: ...
    def content(self, type: PySide6.QtLocation.QPlaceContent.Type, /) -> typing.Dict[int, PySide6.QtLocation.QPlaceContent]: ...
    def detailsFetched(self, /) -> bool: ...
    def extendedAttribute(self, attributeType: str, /) -> PySide6.QtLocation.QPlaceAttribute: ...
    def extendedAttributeTypes(self, /) -> typing.List[str]: ...
    def icon(self, /) -> PySide6.QtLocation.QPlaceIcon: ...
    def insertContent(self, type: PySide6.QtLocation.QPlaceContent.Type, content: typing.Dict[int, PySide6.QtLocation.QPlaceContent], /) -> None: ...
    def isEmpty(self, /) -> bool: ...
    def location(self, /) -> PySide6.QtPositioning.QGeoLocation: ...
    def name(self, /) -> str: ...
    def placeId(self, /) -> str: ...
    def primaryEmail(self, /) -> str: ...
    def primaryFax(self, /) -> str: ...
    def primaryPhone(self, /) -> str: ...
    def primaryWebsite(self, /) -> PySide6.QtCore.QUrl: ...
    def ratings(self, /) -> PySide6.QtLocation.QPlaceRatings: ...
    def removeContactDetails(self, contactType: str, /) -> None: ...
    def removeExtendedAttribute(self, attributeType: str, /) -> None: ...
    def setAttribution(self, attribution: str, /) -> None: ...
    def setCategories(self, categories: collections.abc.Sequence[PySide6.QtLocation.QPlaceCategory], /) -> None: ...
    def setCategory(self, category: PySide6.QtLocation.QPlaceCategory, /) -> None: ...
    def setContactDetails(self, contactType: str, details: collections.abc.Sequence[PySide6.QtLocation.QPlaceContactDetail], /) -> None: ...
    def setContent(self, type: PySide6.QtLocation.QPlaceContent.Type, content: typing.Dict[int, PySide6.QtLocation.QPlaceContent], /) -> None: ...
    def setDetailsFetched(self, fetched: bool, /) -> None: ...
    def setExtendedAttribute(self, attributeType: str, attribute: PySide6.QtLocation.QPlaceAttribute, /) -> None: ...
    def setIcon(self, icon: PySide6.QtLocation.QPlaceIcon, /) -> None: ...
    def setLocation(self, location: PySide6.QtPositioning.QGeoLocation, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setPlaceId(self, identifier: str, /) -> None: ...
    def setRatings(self, ratings: PySide6.QtLocation.QPlaceRatings, /) -> None: ...
    def setSupplier(self, supplier: PySide6.QtLocation.QPlaceSupplier, /) -> None: ...
    def setTotalContentCount(self, type: PySide6.QtLocation.QPlaceContent.Type, total: int, /) -> None: ...
    def setVisibility(self, visibility: PySide6.QtLocation.QLocation.Visibility, /) -> None: ...
    def supplier(self, /) -> PySide6.QtLocation.QPlaceSupplier: ...
    def swap(self, other: PySide6.QtLocation.QPlace, /) -> None: ...
    def totalContentCount(self, type: PySide6.QtLocation.QPlaceContent.Type, /) -> int: ...
    def visibility(self, /) -> PySide6.QtLocation.QLocation.Visibility: ...


class QPlaceAttribute(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceAttribute, /, *, label: str | None = ..., text: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, label: str | None = ..., text: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceAttribute, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceAttribute, /) -> bool: ...
    def isEmpty(self, /) -> bool: ...
    def label(self, /) -> str: ...
    def setLabel(self, label: str, /) -> None: ...
    def setText(self, text: str, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceAttribute, /) -> None: ...
    def text(self, /) -> str: ...


class QPlaceCategory(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceCategory, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceCategory, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceCategory, /) -> bool: ...
    def categoryId(self, /) -> str: ...
    def icon(self, /) -> PySide6.QtLocation.QPlaceIcon: ...
    def isEmpty(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def setCategoryId(self, identifier: str, /) -> None: ...
    def setIcon(self, icon: PySide6.QtLocation.QPlaceIcon, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setVisibility(self, visibility: PySide6.QtLocation.QLocation.Visibility, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceCategory, /) -> None: ...
    def visibility(self, /) -> PySide6.QtLocation.QLocation.Visibility: ...


class QPlaceContactDetail(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceContactDetail, /, *, label: str | None = ..., value: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, label: str | None = ..., value: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceContactDetail, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceContactDetail, /) -> bool: ...
    def clear(self, /) -> None: ...
    def label(self, /) -> str: ...
    def setLabel(self, label: str, /) -> None: ...
    def setValue(self, value: str, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceContactDetail, /) -> None: ...
    def value(self, /) -> str: ...


class QPlaceContent(Shiboken.Object):

    class DataTag(enum.Enum):

        ContentSupplier           = 0x0
        ContentUser               = 0x1
        ContentAttribution        = 0x2
        ImageId                   = 0x3
        ImageUrl                  = 0x4
        ImageMimeType             = 0x5
        EditorialTitle            = 0x6
        EditorialText             = 0x7
        EditorialLanguage         = 0x8
        ReviewId                  = 0x9
        ReviewDateTime            = 0xa
        ReviewTitle               = 0xb
        ReviewText                = 0xc
        ReviewLanguage            = 0xd
        ReviewRating              = 0xe
        CustomDataTag             = 0x3e8

    class Type(enum.Enum):

        NoType                    = 0x0
        ImageType                 = 0x1
        ReviewType                = 0x2
        EditorialType             = 0x3
        CustomType                = 0x100


    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceContent, /) -> None: ...
    @typing.overload
    def __init__(self, /, type: PySide6.QtLocation.QPlaceContent.Type = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtLocation.QPlaceContent | PySide6.QtLocation.QPlaceContent.Type, /) -> bool: ...
    def __ne__(self, other: PySide6.QtLocation.QPlaceContent | PySide6.QtLocation.QPlaceContent.Type, /) -> bool: ...
    def attribution(self, /) -> str: ...
    def dataTags(self, /) -> typing.List[PySide6.QtLocation.QPlaceContent.DataTag]: ...
    def setAttribution(self, attribution: str, /) -> None: ...
    def setSupplier(self, supplier: PySide6.QtLocation.QPlaceSupplier, /) -> None: ...
    def setUser(self, user: PySide6.QtLocation.QPlaceUser, /) -> None: ...
    def setValue(self, tag: PySide6.QtLocation.QPlaceContent.DataTag, arg__2: typing.Any, /) -> None: ...
    def supplier(self, /) -> PySide6.QtLocation.QPlaceSupplier: ...
    def swap(self, other: PySide6.QtLocation.QPlaceContent | PySide6.QtLocation.QPlaceContent.Type, /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceContent.Type: ...
    def user(self, /) -> PySide6.QtLocation.QPlaceUser: ...
    def value(self, tag: PySide6.QtLocation.QPlaceContent.DataTag, /) -> typing.Any: ...


class QPlaceContentReply(PySide6.QtLocation.QPlaceReply):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def content(self, /) -> typing.Dict[int, PySide6.QtLocation.QPlaceContent]: ...
    def nextPageRequest(self, /) -> PySide6.QtLocation.QPlaceContentRequest: ...
    def previousPageRequest(self, /) -> PySide6.QtLocation.QPlaceContentRequest: ...
    def request(self, /) -> PySide6.QtLocation.QPlaceContentRequest: ...
    def setContent(self, content: typing.Dict[int, PySide6.QtLocation.QPlaceContent], /) -> None: ...
    def setNextPageRequest(self, next: PySide6.QtLocation.QPlaceContentRequest, /) -> None: ...
    def setPreviousPageRequest(self, previous: PySide6.QtLocation.QPlaceContentRequest, /) -> None: ...
    def setRequest(self, request: PySide6.QtLocation.QPlaceContentRequest, /) -> None: ...
    def setTotalCount(self, total: int, /) -> None: ...
    def totalCount(self, /) -> int: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceContentRequest(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceContentRequest, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceContentRequest, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceContentRequest, /) -> bool: ...
    def clear(self, /) -> None: ...
    def contentContext(self, /) -> typing.Any: ...
    def contentType(self, /) -> PySide6.QtLocation.QPlaceContent.Type: ...
    def limit(self, /) -> int: ...
    def placeId(self, /) -> str: ...
    def setContentContext(self, context: typing.Any, /) -> None: ...
    def setContentType(self, type: PySide6.QtLocation.QPlaceContent.Type, /) -> None: ...
    def setLimit(self, limit: int, /) -> None: ...
    def setPlaceId(self, identifier: str, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceContentRequest, /) -> None: ...


class QPlaceDetailsReply(PySide6.QtLocation.QPlaceReply):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def place(self, /) -> PySide6.QtLocation.QPlace: ...
    def setPlace(self, place: PySide6.QtLocation.QPlace, /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceIcon(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceIcon, /, *, parameters: typing.Dict[str, typing.Any] | None = ..., manager: PySide6.QtLocation.QPlaceManager | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, parameters: typing.Dict[str, typing.Any] | None = ..., manager: PySide6.QtLocation.QPlaceManager | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceIcon, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceIcon, /) -> bool: ...
    def isEmpty(self, /) -> bool: ...
    def manager(self, /) -> PySide6.QtLocation.QPlaceManager: ...
    def parameters(self, /) -> typing.Dict[str, typing.Any]: ...
    def setManager(self, manager: PySide6.QtLocation.QPlaceManager, /) -> None: ...
    def setParameters(self, parameters: typing.Dict[str, typing.Any], /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceIcon, /) -> None: ...
    def url(self, /, size: PySide6.QtCore.QSize = ...) -> PySide6.QtCore.QUrl: ...


class QPlaceIdReply(PySide6.QtLocation.QPlaceReply):

    class OperationType(enum.Enum):

        SavePlace                 = 0x0
        SaveCategory              = 0x1
        RemovePlace               = 0x2
        RemoveCategory            = 0x3


    def __init__(self, operationType: PySide6.QtLocation.QPlaceIdReply.OperationType, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def id(self, /) -> str: ...
    def operationType(self, /) -> PySide6.QtLocation.QPlaceIdReply.OperationType: ...
    def setId(self, identifier: str, /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceManager(PySide6.QtCore.QObject):

    categoryAdded            : typing.ClassVar[Signal] = ... # categoryAdded(QPlaceCategory,QString)
    categoryRemoved          : typing.ClassVar[Signal] = ... # categoryRemoved(QString,QString)
    categoryUpdated          : typing.ClassVar[Signal] = ... # categoryUpdated(QPlaceCategory,QString)
    dataChanged              : typing.ClassVar[Signal] = ... # dataChanged()
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QPlaceReply*,QPlaceReply::Error,QString); errorOccurred(QPlaceReply*,QPlaceReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QPlaceReply*)
    placeAdded               : typing.ClassVar[Signal] = ... # placeAdded(QString)
    placeRemoved             : typing.ClassVar[Signal] = ... # placeRemoved(QString)
    placeUpdated             : typing.ClassVar[Signal] = ... # placeUpdated(QString)
    def category(self, categoryId: str, /) -> PySide6.QtLocation.QPlaceCategory: ...
    def childCategories(self, /, parentId: str = ...) -> typing.List[PySide6.QtLocation.QPlaceCategory]: ...
    def childCategoryIds(self, /, parentId: str = ...) -> typing.List[str]: ...
    def compatiblePlace(self, place: PySide6.QtLocation.QPlace, /) -> PySide6.QtLocation.QPlace: ...
    def getPlaceContent(self, request: PySide6.QtLocation.QPlaceContentRequest, /) -> PySide6.QtLocation.QPlaceContentReply: ...
    def getPlaceDetails(self, placeId: str, /) -> PySide6.QtLocation.QPlaceDetailsReply: ...
    def initializeCategories(self, /) -> PySide6.QtLocation.QPlaceReply: ...
    def locales(self, /) -> typing.List[PySide6.QtCore.QLocale]: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def matchingPlaces(self, request: PySide6.QtLocation.QPlaceMatchRequest, /) -> PySide6.QtLocation.QPlaceMatchReply: ...
    def parentCategoryId(self, categoryId: str, /) -> str: ...
    def removeCategory(self, categoryId: str, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def removePlace(self, placeId: str, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def saveCategory(self, category: PySide6.QtLocation.QPlaceCategory, /, parentId: str = ...) -> PySide6.QtLocation.QPlaceIdReply: ...
    def savePlace(self, place: PySide6.QtLocation.QPlace, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def search(self, query: PySide6.QtLocation.QPlaceSearchRequest, /) -> PySide6.QtLocation.QPlaceSearchReply: ...
    def searchSuggestions(self, request: PySide6.QtLocation.QPlaceSearchRequest, /) -> PySide6.QtLocation.QPlaceSearchSuggestionReply: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setLocales(self, locale: collections.abc.Sequence[PySide6.QtCore.QLocale], /) -> None: ...


class QPlaceManagerEngine(PySide6.QtCore.QObject):

    categoryAdded            : typing.ClassVar[Signal] = ... # categoryAdded(QPlaceCategory,QString)
    categoryRemoved          : typing.ClassVar[Signal] = ... # categoryRemoved(QString,QString)
    categoryUpdated          : typing.ClassVar[Signal] = ... # categoryUpdated(QPlaceCategory,QString)
    dataChanged              : typing.ClassVar[Signal] = ... # dataChanged()
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QPlaceReply*,QPlaceReply::Error,QString); errorOccurred(QPlaceReply*,QPlaceReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished(QPlaceReply*)
    placeAdded               : typing.ClassVar[Signal] = ... # placeAdded(QString)
    placeRemoved             : typing.ClassVar[Signal] = ... # placeRemoved(QString)
    placeUpdated             : typing.ClassVar[Signal] = ... # placeUpdated(QString)

    def __init__(self, parameters: typing.Dict[str, typing.Any], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def category(self, categoryId: str, /) -> PySide6.QtLocation.QPlaceCategory: ...
    def childCategories(self, parentId: str, /) -> typing.List[PySide6.QtLocation.QPlaceCategory]: ...
    def childCategoryIds(self, categoryId: str, /) -> typing.List[str]: ...
    def compatiblePlace(self, original: PySide6.QtLocation.QPlace, /) -> PySide6.QtLocation.QPlace: ...
    def constructIconUrl(self, icon: PySide6.QtLocation.QPlaceIcon, size: PySide6.QtCore.QSize, /) -> PySide6.QtCore.QUrl: ...
    def getPlaceContent(self, request: PySide6.QtLocation.QPlaceContentRequest, /) -> PySide6.QtLocation.QPlaceContentReply: ...
    def getPlaceDetails(self, placeId: str, /) -> PySide6.QtLocation.QPlaceDetailsReply: ...
    def initializeCategories(self, /) -> PySide6.QtLocation.QPlaceReply: ...
    def locales(self, /) -> typing.List[PySide6.QtCore.QLocale]: ...
    def manager(self, /) -> PySide6.QtLocation.QPlaceManager: ...
    def managerName(self, /) -> str: ...
    def managerVersion(self, /) -> int: ...
    def matchingPlaces(self, request: PySide6.QtLocation.QPlaceMatchRequest, /) -> PySide6.QtLocation.QPlaceMatchReply: ...
    def parentCategoryId(self, categoryId: str, /) -> str: ...
    def removeCategory(self, categoryId: str, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def removePlace(self, placeId: str, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def saveCategory(self, category: PySide6.QtLocation.QPlaceCategory, parentId: str, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def savePlace(self, place: PySide6.QtLocation.QPlace, /) -> PySide6.QtLocation.QPlaceIdReply: ...
    def search(self, request: PySide6.QtLocation.QPlaceSearchRequest, /) -> PySide6.QtLocation.QPlaceSearchReply: ...
    def searchSuggestions(self, request: PySide6.QtLocation.QPlaceSearchRequest, /) -> PySide6.QtLocation.QPlaceSearchSuggestionReply: ...
    def setLocales(self, locales: collections.abc.Sequence[PySide6.QtCore.QLocale], /) -> None: ...


class QPlaceMatchReply(PySide6.QtLocation.QPlaceReply):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def places(self, /) -> typing.List[PySide6.QtLocation.QPlace]: ...
    def request(self, /) -> PySide6.QtLocation.QPlaceMatchRequest: ...
    def setPlaces(self, results: collections.abc.Sequence[PySide6.QtLocation.QPlace], /) -> None: ...
    def setRequest(self, request: PySide6.QtLocation.QPlaceMatchRequest, /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceMatchRequest(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceMatchRequest, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceMatchRequest, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceMatchRequest, /) -> bool: ...
    def clear(self, /) -> None: ...
    def parameters(self, /) -> typing.Dict[str, typing.Any]: ...
    def places(self, /) -> typing.List[PySide6.QtLocation.QPlace]: ...
    def setParameters(self, parameters: typing.Dict[str, typing.Any], /) -> None: ...
    def setPlaces(self, places: collections.abc.Sequence[PySide6.QtLocation.QPlace], /) -> None: ...
    def setResults(self, results: collections.abc.Sequence[PySide6.QtLocation.QPlaceSearchResult], /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceMatchRequest, /) -> None: ...


class QPlaceProposedSearchResult(PySide6.QtLocation.QPlaceSearchResult):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceSearchResult, /) -> None: ...

    def searchRequest(self, /) -> PySide6.QtLocation.QPlaceSearchRequest: ...
    def setSearchRequest(self, request: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...


class QPlaceRatings(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceRatings, /, *, average: float | None = ..., maximum: float | None = ..., count: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, average: float | None = ..., maximum: float | None = ..., count: int | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceRatings, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceRatings, /) -> bool: ...
    def average(self, /) -> float: ...
    def count(self, /) -> int: ...
    def isEmpty(self, /) -> bool: ...
    def maximum(self, /) -> float: ...
    def setAverage(self, average: float, /) -> None: ...
    def setCount(self, count: int, /) -> None: ...
    def setMaximum(self, max: float, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceRatings, /) -> None: ...


class QPlaceReply(PySide6.QtCore.QObject):

    aborted                  : typing.ClassVar[Signal] = ... # aborted()
    contentUpdated           : typing.ClassVar[Signal] = ... # contentUpdated()
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QPlaceReply::Error,QString); errorOccurred(QPlaceReply::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished()

    class Error(enum.Enum):

        NoError                   = 0x0
        PlaceDoesNotExistError    = 0x1
        CategoryDoesNotExistError = 0x2
        CommunicationError        = 0x3
        ParseError                = 0x4
        PermissionsError          = 0x5
        UnsupportedError          = 0x6
        BadArgumentError          = 0x7
        CancelError               = 0x8
        UnknownError              = 0x9

    class Type(enum.Enum):

        Reply                     = 0x0
        DetailsReply              = 0x1
        SearchReply               = 0x2
        SearchSuggestionReply     = 0x3
        ContentReply              = 0x4
        IdReply                   = 0x5
        MatchReply                = 0x6


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def abort(self, /) -> None: ...
    def error(self, /) -> PySide6.QtLocation.QPlaceReply.Error: ...
    def errorString(self, /) -> str: ...
    def isFinished(self, /) -> bool: ...
    def setError(self, error: PySide6.QtLocation.QPlaceReply.Error, errorString: str, /) -> None: ...
    def setFinished(self, finished: bool, /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceResult(PySide6.QtLocation.QPlaceSearchResult):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceSearchResult, /) -> None: ...

    def distance(self, /) -> float: ...
    def isSponsored(self, /) -> bool: ...
    def place(self, /) -> PySide6.QtLocation.QPlace: ...
    def setDistance(self, distance: float, /) -> None: ...
    def setPlace(self, place: PySide6.QtLocation.QPlace, /) -> None: ...
    def setSponsored(self, sponsored: bool, /) -> None: ...


class QPlaceSearchReply(PySide6.QtLocation.QPlaceReply):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def nextPageRequest(self, /) -> PySide6.QtLocation.QPlaceSearchRequest: ...
    def previousPageRequest(self, /) -> PySide6.QtLocation.QPlaceSearchRequest: ...
    def request(self, /) -> PySide6.QtLocation.QPlaceSearchRequest: ...
    def results(self, /) -> typing.List[PySide6.QtLocation.QPlaceSearchResult]: ...
    def setNextPageRequest(self, next: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...
    def setPreviousPageRequest(self, previous: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...
    def setRequest(self, request: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...
    def setResults(self, results: collections.abc.Sequence[PySide6.QtLocation.QPlaceSearchResult], /) -> None: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceSearchRequest(Shiboken.Object):

    class RelevanceHint(enum.Enum):

        UnspecifiedHint           = 0x0
        DistanceHint              = 0x1
        LexicalPlaceNameHint      = 0x2


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...

    def __eq__(self, rhs: PySide6.QtLocation.QPlaceSearchRequest, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceSearchRequest, /) -> bool: ...
    def categories(self, /) -> typing.List[PySide6.QtLocation.QPlaceCategory]: ...
    def clear(self, /) -> None: ...
    def limit(self, /) -> int: ...
    def recommendationId(self, /) -> str: ...
    def relevanceHint(self, /) -> PySide6.QtLocation.QPlaceSearchRequest.RelevanceHint: ...
    def searchArea(self, /) -> PySide6.QtPositioning.QGeoShape: ...
    def searchContext(self, /) -> typing.Any: ...
    def searchTerm(self, /) -> str: ...
    def setCategories(self, categories: collections.abc.Sequence[PySide6.QtLocation.QPlaceCategory], /) -> None: ...
    def setCategory(self, category: PySide6.QtLocation.QPlaceCategory, /) -> None: ...
    def setLimit(self, limit: int, /) -> None: ...
    def setRecommendationId(self, recommendationId: str, /) -> None: ...
    def setRelevanceHint(self, hint: PySide6.QtLocation.QPlaceSearchRequest.RelevanceHint, /) -> None: ...
    def setSearchArea(self, area: PySide6.QtPositioning.QGeoShape, /) -> None: ...
    def setSearchContext(self, context: typing.Any, /) -> None: ...
    def setSearchTerm(self, term: str, /) -> None: ...
    def setVisibilityScope(self, visibilityScopes: PySide6.QtLocation.QLocation.Visibility, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceSearchRequest, /) -> None: ...
    def visibilityScope(self, /) -> PySide6.QtLocation.QLocation.Visibility: ...


class QPlaceSearchResult(Shiboken.Object):

    class SearchResultType(enum.Enum):

        UnknownSearchResult       = 0x0
        PlaceResult               = 0x1
        ProposedSearchResult      = 0x2


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceSearchResult, /) -> None: ...

    def __eq__(self, other: PySide6.QtLocation.QPlaceSearchResult, /) -> bool: ...
    def __ne__(self, other: PySide6.QtLocation.QPlaceSearchResult, /) -> bool: ...
    def icon(self, /) -> PySide6.QtLocation.QPlaceIcon: ...
    def setIcon(self, icon: PySide6.QtLocation.QPlaceIcon, /) -> None: ...
    def setTitle(self, title: str, /) -> None: ...
    def title(self, /) -> str: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceSearchResult.SearchResultType: ...


class QPlaceSearchSuggestionReply(PySide6.QtLocation.QPlaceReply):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def setSuggestions(self, suggestions: collections.abc.Sequence[str], /) -> None: ...
    def suggestions(self, /) -> typing.List[str]: ...
    def type(self, /) -> PySide6.QtLocation.QPlaceReply.Type: ...


class QPlaceSupplier(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceSupplier, /, *, name: str | None = ..., supplierId: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtLocation.QPlaceIcon | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, name: str | None = ..., supplierId: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtLocation.QPlaceIcon | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceSupplier, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceSupplier, /) -> bool: ...
    def icon(self, /) -> PySide6.QtLocation.QPlaceIcon: ...
    def isEmpty(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def setIcon(self, icon: PySide6.QtLocation.QPlaceIcon, /) -> None: ...
    def setName(self, data: str, /) -> None: ...
    def setSupplierId(self, identifier: str, /) -> None: ...
    def setUrl(self, data: PySide6.QtCore.QUrl | str, /) -> None: ...
    def supplierId(self, /) -> str: ...
    def swap(self, other: PySide6.QtLocation.QPlaceSupplier, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QPlaceUser(Shiboken.Object):

    @typing.overload
    def __init__(self, other: PySide6.QtLocation.QPlaceUser, /, *, userId: str | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, userId: str | None = ..., name: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtLocation.QPlaceUser, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtLocation.QPlaceUser, /) -> bool: ...
    def name(self, /) -> str: ...
    def setName(self, name: str, /) -> None: ...
    def setUserId(self, identifier: str, /) -> None: ...
    def swap(self, other: PySide6.QtLocation.QPlaceUser, /) -> None: ...
    def userId(self, /) -> str: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2023 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations

from . import events
from . import futures
import traceback

from typing import Any, Optional

import asyncio
import collections.abc
import concurrent.futures
import contextvars


class QAsyncioTask(futures.QAsyncioFuture):
    """ https://docs.python.org/3/library/asyncio-task.html """

    def __init__(self, coro: collections.abc.Generator | collections.abc.Coroutine, *,
                 loop: "events.QAsyncioEventLoop | None" = None, name: str | None = None,
                 context: contextvars.Context | None = None) -> None:
        super().__init__(loop=loop, context=context)
        self._source_traceback = None  # required for Python < 3.11

        self._state: futures.QAsyncioFuture.FutureState = futures.QAsyncioFuture.FutureState.PENDING
        self._exception: Optional[BaseException] = None

        self._coro = coro  # The coroutine for which this task was created.
        self._name = name if name else "QtTask"

        # The task creates a handle for its coroutine. The handle enqueues the
        # task's step function as its callback in the event loop.
        self._loop.call_soon(self._step, context=self._context)

        # The task step function executes the coroutine until it finishes,
        # raises an exception or returns a future. If a future was returned,
        # the task will await its completion (or exception). If the task is
        # cancelled while it awaits a future, this future must also be
        # cancelled in order for the cancellation to be successful.
        self._future_to_await: asyncio.Future | None = None

        self._cancelled = False  # PYSIDE-2644; see _step
        self._cancel_count = 0
        self._cancel_message: str | None = None
        # Store traceback in case of Exception. Useful when exception happens in coroutine
        self._tb: str | None = None

        # https://docs.python.org/3/library/asyncio-extending.html#task-lifetime-support
        asyncio._register_task(self)  # type: ignore[arg-type]

    def __repr__(self) -> str:
        state: str = "Unknown"
        if self._state == futures.QAsyncioFuture.FutureState.PENDING:
            state = "Pending"
        elif self._state == futures.QAsyncioFuture.FutureState.DONE_WITH_RESULT:
            state = "Done"
        elif self._state == futures.QAsyncioFuture.FutureState.DONE_WITH_EXCEPTION:
            state = f"Done with exception ({repr(self._exception)})"
        elif self._state == futures.QAsyncioFuture.FutureState.CANCELLED:
            state = "Cancelled"

        return f"Task '{self.get_name()}' with state: {state}"

    class QtTaskApiMisuseError(Exception):
        pass

    def set_result(self, result: Any) -> None:  # type: ignore[override]
        # This function is not inherited from the Future APIs.
        raise QAsyncioTask.QtTaskApiMisuseError("Tasks cannot set results")

    def set_exception(self, exception: Any) -> None:  # type: ignore[override]
        # This function is not inherited from the Future APIs.
        raise QAsyncioTask.QtTaskApiMisuseError("Tasks cannot set exceptions")

    def _step(self,
              exception_or_future: BaseException | futures.QAsyncioFuture | None = None) -> None:
        """
        The step function is the heart of a task. It is scheduled in the event
        loop repeatedly, executing the coroutine "step" by "step" (i.e.,
        iterating through the asynchronous generator) until it finishes with an
        exception or successfully. Each step can optionally receive an
        exception or a future as a result from a previous step to handle.
        """

        if self.done():
            return
        result = None
        self._future_to_await = None

        if self._cancelled:
            exception_or_future = asyncio.CancelledError(self._cancel_message)
            self._cancelled = False

        if asyncio.futures.isfuture(exception_or_future):
            try:
                exception_or_future.result()
            except BaseException as e:
                exception_or_future = e

        try:
            asyncio._enter_task(self._loop, self)  # type: ignore[arg-type]

            # It is at this point that the coroutine is resumed for the current
            # step (i.e. asynchronous generator iteration). It will now be
            # executed until it yields (and potentially returns a future),
            # raises an exception, is cancelled, or finishes successfully.

            if isinstance(exception_or_future, BaseException):
                # If the coroutine doesn't handle this exception, it propagates
                # to the caller.
                result = self._coro.throw(exception_or_future)
            else:
                result = self._coro.send(None)
        except StopIteration as e:
            self._state = futures.QAsyncioFuture.FutureState.DONE_WITH_RESULT
            self._result = e.value
        except (concurrent.futures.CancelledError, asyncio.exceptions.CancelledError) as e:
            self._state = futures.QAsyncioFuture.FutureState.CANCELLED
            self._exception = e
        except BaseException as e:
            self._state = futures.QAsyncioFuture.FutureState.DONE_WITH_EXCEPTION
            self._exception = e
            self._tb = traceback.format_exc()
        else:
            if asyncio.futures.isfuture(result):
                # If the coroutine yields a future, the task will await its
                # completion, and at that point the step function will be
                # called again.
                result.add_done_callback(
                    self._step, context=self._context)  # type: ignore[arg-type]

                # The task will await the completion (or exception) of this
                # future. If the task is cancelled while it awaits a future,
                # this future must also be cancelled.
                self._future_to_await = result

                if self._cancelled:
                    # PYSIDE-2644: If the task was cancelled at this step and a
                    # new future was created to be awaited, then it should be
                    # cancelled as well. Otherwise, in some scenarios like a
                    # loop inside the task and with bad timing, if the new
                    # future is not cancelled, the task would continue running
                    # in this loop despite having been cancelled. This bad
                    # timing can occur especially if the first future finishes
                    # very quickly.
                    self._future_to_await.cancel(self._cancel_message)
            elif result is None:
                # If no future was yielded, we schedule the step function again
                # without any arguments.
                self._loop.call_soon(self._step, context=self._context)
            else:
                # This is not supposed to happen.
                exception = RuntimeError(f"Bad task result: {result}")
                self._loop.call_soon(self._step, exception, context=self._context)
        finally:
            asyncio._leave_task(self._loop, self)  # type: ignore[arg-type]

            if self._exception:
                message = str(self._exception)
                if message == "None":
                    message = ""
                else:
                    message = "An exception occurred during task execution"
                self._loop.call_exception_handler({
                    "message": message,
                    "exception": self._exception,
                    "task": self,
                    "future": (exception_or_future
                               if asyncio.futures.isfuture(exception_or_future)
                               else None),
                    "traceback": self._tb
                })

            if self.done():
                self._schedule_callbacks()

                # https://docs.python.org/3/library/asyncio-extending.html#task-lifetime-support
                asyncio._unregister_task(self)  # type: ignore[arg-type]

    def get_stack(self, *, limit=None) -> list[Any]:
        # TODO
        raise NotImplementedError("QtTask.get_stack is not implemented")

    def print_stack(self, *, limit=None, file=None) -> None:
        # TODO
        raise NotImplementedError("QtTask.print_stack is not implemented")

    def get_coro(self) -> collections.abc.Generator | collections.abc.Coroutine:
        return self._coro

    def get_name(self) -> str:
        return self._name

    def set_name(self, value) -> None:
        self._name = str(value)

    def cancel(self, msg: str | None = None) -> bool:
        if self.done():
            return False
        self._cancel_count += 1
        self._cancel_message = msg
        if self._future_to_await is not None:
            # A task that is awaiting a future must also cancel this future in
            # order for the cancellation to be successful.
            self._future_to_await.cancel(msg)
        self._cancelled = True  # PYSIDE-2644; see _step
        return True

    def uncancel(self) -> int:
        if self._cancel_count > 0:
            self._cancel_count -= 1
        return self._cancel_count

    def cancelling(self) -> int:
        return self._cancel_count



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtTextToSpeech, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtTextToSpeech`

import PySide6.QtTextToSpeech
import PySide6.QtCore

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QTextToSpeech(PySide6.QtCore.QObject):

    aboutToSynthesize        : typing.ClassVar[Signal] = ... # aboutToSynthesize(qsizetype)
    engineChanged            : typing.ClassVar[Signal] = ... # engineChanged(QString)
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QTextToSpeech::ErrorReason,QString)
    localeChanged            : typing.ClassVar[Signal] = ... # localeChanged(QLocale)
    pitchChanged             : typing.ClassVar[Signal] = ... # pitchChanged(double)
    rateChanged              : typing.ClassVar[Signal] = ... # rateChanged(double)
    sayingWord               : typing.ClassVar[Signal] = ... # sayingWord(QString,qsizetype,qsizetype,qsizetype)
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QTextToSpeech::State)
    voiceChanged             : typing.ClassVar[Signal] = ... # voiceChanged(QVoice)
    volumeChanged            : typing.ClassVar[Signal] = ... # volumeChanged(double)

    class BoundaryHint(enum.Enum):

        Default                   = 0x0
        Immediate                 = 0x1
        Word                      = 0x2
        Sentence                  = 0x3
        Utterance                 = 0x4

    class Capability(enum.Flag):

        None_                     = 0x0
        Speak                     = 0x1
        PauseResume               = 0x2
        WordByWordProgress        = 0x4
        Synthesize                = 0x8

    class ErrorReason(enum.Enum):

        NoError                   = 0x0
        Initialization            = 0x1
        Configuration             = 0x2
        Input                     = 0x3
        Playback                  = 0x4

    class State(enum.Enum):

        Ready                     = 0x0
        Speaking                  = 0x1
        Paused                    = 0x2
        Error                     = 0x3
        Synthesizing              = 0x4


    @typing.overload
    def __init__(self, engine: str, params: typing.Dict[str, typing.Any], /, parent: PySide6.QtCore.QObject | None = ..., *, state: PySide6.QtTextToSpeech.QTextToSpeech.State | None = ..., volume: float | None = ..., rate: float | None = ..., pitch: float | None = ..., locale: PySide6.QtCore.QLocale | None = ..., voice: PySide6.QtTextToSpeech.QVoice | None = ..., engineCapabilities: PySide6.QtTextToSpeech.QTextToSpeech.Capability | None = ...) -> None: ...
    @typing.overload
    def __init__(self, engine: str, /, parent: PySide6.QtCore.QObject | None = ..., *, state: PySide6.QtTextToSpeech.QTextToSpeech.State | None = ..., volume: float | None = ..., rate: float | None = ..., pitch: float | None = ..., locale: PySide6.QtCore.QLocale | None = ..., voice: PySide6.QtTextToSpeech.QVoice | None = ..., engineCapabilities: PySide6.QtTextToSpeech.QTextToSpeech.Capability | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, engine: str | None = ..., state: PySide6.QtTextToSpeech.QTextToSpeech.State | None = ..., volume: float | None = ..., rate: float | None = ..., pitch: float | None = ..., locale: PySide6.QtCore.QLocale | None = ..., voice: PySide6.QtTextToSpeech.QVoice | None = ..., engineCapabilities: PySide6.QtTextToSpeech.QTextToSpeech.Capability | None = ...) -> None: ...

    def allVoices(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> typing.List[PySide6.QtTextToSpeech.QVoice]: ...
    @staticmethod
    def availableEngines() -> typing.List[str]: ...
    def availableLocales(self, /) -> typing.List[PySide6.QtCore.QLocale]: ...
    def availableVoices(self, /) -> typing.List[PySide6.QtTextToSpeech.QVoice]: ...
    def engine(self, /) -> str: ...
    def engineCapabilities(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.Capability: ...
    def enqueue(self, text: str, /) -> int: ...
    def errorReason(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.ErrorReason: ...
    def errorString(self, /) -> str: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def pause(self, /, boundaryHint: PySide6.QtTextToSpeech.QTextToSpeech.BoundaryHint = ...) -> None: ...
    def pitch(self, /) -> float: ...
    def rate(self, /) -> float: ...
    def resume(self, /) -> None: ...
    def say(self, text: str, /) -> None: ...
    def setEngine(self, engine: str, /, params: typing.Dict[str, typing.Any] = ...) -> bool: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setPitch(self, pitch: float, /) -> None: ...
    def setRate(self, rate: float, /) -> None: ...
    def setVoice(self, voice: PySide6.QtTextToSpeech.QVoice, /) -> None: ...
    def setVolume(self, volume: float, /) -> None: ...
    def state(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.State: ...
    def stop(self, /, boundaryHint: PySide6.QtTextToSpeech.QTextToSpeech.BoundaryHint = ...) -> None: ...
    def voice(self, /) -> PySide6.QtTextToSpeech.QVoice: ...
    def volume(self, /) -> float: ...


class QTextToSpeechEngine(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QTextToSpeech::ErrorReason,QString)
    sayingWord               : typing.ClassVar[Signal] = ... # sayingWord(QString,qsizetype,qsizetype)
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QTextToSpeech::State)
    synthesized              : typing.ClassVar[Signal] = ... # synthesized(QAudioFormat,QByteArray)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def availableLocales(self, /) -> typing.List[PySide6.QtCore.QLocale]: ...
    def availableVoices(self, /) -> typing.List[PySide6.QtTextToSpeech.QVoice]: ...
    def capabilities(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.Capability: ...
    @staticmethod
    def createVoice(name: str, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, gender: PySide6.QtTextToSpeech.QVoice.Gender, age: PySide6.QtTextToSpeech.QVoice.Age, data: typing.Any, /) -> PySide6.QtTextToSpeech.QVoice: ...
    def errorReason(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.ErrorReason: ...
    def errorString(self, /) -> str: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def pause(self, boundaryHint: PySide6.QtTextToSpeech.QTextToSpeech.BoundaryHint, /) -> None: ...
    def pitch(self, /) -> float: ...
    def rate(self, /) -> float: ...
    def resume(self, /) -> None: ...
    def say(self, text: str, /) -> None: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> bool: ...
    def setPitch(self, pitch: float, /) -> bool: ...
    def setRate(self, rate: float, /) -> bool: ...
    def setVoice(self, voice: PySide6.QtTextToSpeech.QVoice, /) -> bool: ...
    def setVolume(self, volume: float, /) -> bool: ...
    def state(self, /) -> PySide6.QtTextToSpeech.QTextToSpeech.State: ...
    def stop(self, boundaryHint: PySide6.QtTextToSpeech.QTextToSpeech.BoundaryHint, /) -> None: ...
    def synthesize(self, text: str, /) -> None: ...
    def voice(self, /) -> PySide6.QtTextToSpeech.QVoice: ...
    @staticmethod
    def voiceData(voice: PySide6.QtTextToSpeech.QVoice, /) -> typing.Any: ...
    def volume(self, /) -> float: ...


class QVoice(Shiboken.Object):

    class Age(enum.Enum):

        Child                     = 0x0
        Teenager                  = 0x1
        Adult                     = 0x2
        Senior                    = 0x3
        Other                     = 0x4

    class Gender(enum.Enum):

        Male                      = 0x0
        Female                    = 0x1
        Unknown                   = 0x2


    @typing.overload
    def __init__(self, other: PySide6.QtTextToSpeech.QVoice, /, *, name: str | None = ..., gender: PySide6.QtTextToSpeech.QVoice.Gender | None = ..., age: PySide6.QtTextToSpeech.QVoice.Age | None = ..., locale: PySide6.QtCore.QLocale | None = ..., language: PySide6.QtCore.QLocale.Language | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, name: str | None = ..., gender: PySide6.QtTextToSpeech.QVoice.Gender | None = ..., age: PySide6.QtTextToSpeech.QVoice.Age | None = ..., locale: PySide6.QtCore.QLocale | None = ..., language: PySide6.QtCore.QLocale.Language | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtTextToSpeech.QVoice, /) -> bool: ...
    def __lshift__(self, str: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, rhs: PySide6.QtTextToSpeech.QVoice, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, str: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def age(self, /) -> PySide6.QtTextToSpeech.QVoice.Age: ...
    @staticmethod
    def ageName(age: PySide6.QtTextToSpeech.QVoice.Age, /) -> str: ...
    def gender(self, /) -> PySide6.QtTextToSpeech.QVoice.Gender: ...
    @staticmethod
    def genderName(gender: PySide6.QtTextToSpeech.QVoice.Gender, /) -> str: ...
    def language(self, /) -> PySide6.QtCore.QLocale.Language: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def name(self, /) -> str: ...
    def swap(self, other: PySide6.QtTextToSpeech.QVoice, /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtQuickControls2, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtQuickControls2`

import PySide6.QtQuickControls2
import PySide6.QtCore

import typing
import collections.abc
from shiboken6 import Shiboken


class QIntList: ...


class QQuickAttachedPropertyPropagator(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def attachedChildren(self, /) -> typing.List[PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator]: ...
    def attachedParent(self, /) -> PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator: ...
    def attachedParentChange(self, newParent: PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator, oldParent: PySide6.QtQuickControls2.QQuickAttachedPropertyPropagator, /) -> None: ...
    def initialize(self, /) -> None: ...


class QQuickStyle(Shiboken.Object):

    def __init__(self, /) -> None: ...

    @staticmethod
    def name() -> str: ...
    @staticmethod
    def setFallbackStyle(style: str, /) -> None: ...
    @staticmethod
    def setStyle(style: str, /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
